SystemOrganization addCategory: #ScriptLoader20!

Object subclass: #Loader
	instanceVariableNames: ''
	classVariableNames: 'PackagesBeforeLastLoad'
	poolDictionaries: ''
	category: 'ScriptLoader20'!

!Loader commentStamp: 'LaurentLaffont 3/4/2011 22:44' prior: 0!
I'm an abstract class which collect some infos about package and system (versions, dirty).
#currentChangedPackages instance method and #currentMajorVersionNumber class are missing and provided by my wellknown subclass ScriptLoader (see ScriptLoader comment).


Stef: This is a class that was extracted from scriptLoader because I want to slowly get in place a loader infrastructure based on Metacello.!

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
packageToBeTestedFolderName

	^ 'packages-to-be-tested'! !

!Loader class methodsFor: 'private' stamp: 'CamilloBruni 5/26/2012 12:18'!
waitingCacheFolder
	^ self packageToBeTestedFolderName asFileReference 
		ensureDirectory;
		yourself

	! !

!Loader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2010 17:41'!
allCurrentVersions
	"self new allCurrentVersions"
	
	| copies names |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	names := copies collect:
		[:ea |  ea ancestry ancestorString ].
	^ names reject: #isEmpty! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:51'!
currentChangedPackages
	"self new currentChangedPackages" 
	
	^  self currentPackages select: [:each |
		each needsSaving or: [
			(PackagesBeforeLastLoad includes: each ancestry ancestorString) not ] ]! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumber

	^ self class currentMajorVersionNumber ! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumberWithoutDot
	"self new currentMajorVersionNumberWithoutDot"
	^ self class currentMajorVersionNumber asString copyWithout: $.! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:42'!
currentVersionsToBeSaved
	"self new currentVersionsToBeSaved"
	
	^ self allCurrentVersions reject: [ :each |
		self packagesNotToSavePatternNames
			anySatisfy: [ :p | p match: each ] ]! !

!Loader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 9/10/2010 17:51'!
diffPackages
	"return a list of packages that are new. They can be dirty or not."
	"self new diffPackages"
	 
	| diff |
	diff := Set new.
	self currentVersionsToBeSaved do: [:each |
		(PackagesBeforeLastLoad includes: each) ifFalse: [diff add: each]].
	^ diff
	! !

!Loader methodsFor: 'initialize' stamp: 'StephaneDucasse 9/10/2010 17:49'!
initialize
	super initialize.
	PackagesBeforeLastLoad ifNil: [ PackagesBeforeLastLoad := Set new ]! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
markPackagesBeforeNewCodeIsLoaded
	"Use this method to keep a log of all the packages that were loaded before loading new code. This will help the system to perform a diff and know after what to publish."
	
	"self new markPackagesBeforeNewCodeIsLoaded"
	
	PackagesBeforeLastLoad := self currentVersionsToBeSaved! !

!Loader methodsFor: 'private' stamp: 'MarcusDenker 10/21/2012 11:07'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'SLICE*'
			'Slice*'
			'slice*'
		).! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
resetPackagesBeforeLastLoad
	PackagesBeforeLastLoad := Set new! !

Loader subclass: #ScriptLoader
	instanceVariableNames: 'repository inboxRepository repository39 repositorySqueakTrunk repository310 repositoryTaskForces repositoryMC repositoryTreated'
	classVariableNames: 'CheckImageInSyncWithUpdate CurrentMajorVersionNumber CurrentScriptVersionNumber CurrentUpdateVersionNumber CurrentlyIntegratingChanges LogStream Repository'
	poolDictionaries: 'TextConstants'
	category: 'ScriptLoader20'!

!ScriptLoader commentStamp: 'StephaneDucasse 5/26/2010 20:49' prior: 0!
Pharo Process Description


---
Here is the pharo process.

General points
-----------------------
An enhancement
	- should be added to the bug tracker
	- announced to the mailing-list
	- asked for feedback 
	- results should be added to the BT entry

Fixed tag means ready for integration
Closed tag means integrated

A bug detected
	- discuss via the mailing-list
	- should be added to the bug tracker
	- fix are considered as enh (see point above)

When a fix is fixed it should be either post as cs to the BT entry or in the PharoInbox
as a Slice (a slice is an emtpy package that has as requirement other package composing the fix).

We have three projects:
	Pharo
	PharoInbox
	PharoTreatedInbox

A fix goes either from inbox to treatedInbox or to Pharo.
If a fix does not work it is moved to the TreatedInbox.
If a fix works it is integrated as follow - it will be moved from the Inbox to the TreatedInbox
and integrated and published in the Pharo project

To help browsing multiple repositories:

ScriptLoader new addExtraRepositories


+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Now the integration works in 4 main steps which can be steered by the following expression
ScriptLoader releaseMenu
or via the menu that can be shown/hidden using 
	ScriptLoader showIntegrationMenu
	ScriptLoader hideIntegrationMenu


1.) Start up a recent and clean image
	ScriptLoader new prepareNewUpdate
	
	This step will 
		- load the latest updates
		- load the latest ScriptLoader package from the Pharo repository.
		Indeed when we work on improving the ScriptLoader it may not be published in the update stream. 
		New versions can be available on the server but not part of the latest updates.
		Therefore the process always loads the latest version of scriptloader from the pharo repository.
		This point is important because when an integration failed, you have to check and optionally 
		remove the scriptloader package from the pharo repository.
		
		- check that the update.list (which contains the cs to load the packages) is in sync
		with the image current version. You have to download the latest version using a script like this one.
		Pay attention to update it so that it reflects the right version (ie 1.0, 1.1, 1.2...)
		     scp -p LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/updates.list .
		- snapshot the package version to detect dirty or changed but non dirty packages.

2.) Apply changes

	ScriptLoader new doneApplyingChanges
	
	This step will 
		- create an update method with can trigger the load of the packages and some pre/post actions
		- create a script method with describes all the package versions and it used by the update methods
		- save all the packages that are different (except some filtered packages)	
		into a local folder named package-to-be-tested.
		ScriptLoader, SLICE*.... and a couple of other packages are not considered to be included in the script method
			(check method packagesNotToSavePatternNames)
		

3.) Verify changes
	==> in a ***new*** image (in the current folder) execute:
	ScriptLoader new verifyNewUpdate

	This step will 
		- load in any order (so may break) the package previously saved
		in the packages to be tested.
		- this step is important because you may get simple changes with unexpected side effects and that 
		may break the load.
		

4.) If there are problems go to 2.) to fix them, else:
	ScriptLoader new publishChanges

	This step will
		- generate a new cs file whose purpose is to load the given version of the scriptloader and trigger the 
		correct update method.
		- add the name of the cs file to the end of the updates.list file local to the disc
		- copy all the package from the local directory to the Pharo
		
	After the updates.list and the cs file should be manually uploaded to the ftp (see below) 
	   scp "$1" LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/
	

5) in case of problems.
Think that if you pass the step 4 you may have a scriptLoader version that got published and that is reloaded 
during the first step.



CurrentMajorVersionNumber should contains a string '1.0', '1.1'....
This string will determine on which folder on the server the updates.list should be loaded.
	i.e., updates/pharo1.0, updates/pharo1.1 ....

--- Not to forget ---
To change the release stream
add a new method for each releaseStream
	ScriptLoader toPharoOne
	ScriptLoader toPharoOneDotOne
!

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 9/10/2010 17:28'!
checkImageInSyncWithUpdate
	"most of the time you want to make sure that your image is in sync with the latest item of the update.list
	but in some cases you do not to get forced to have this behavior."
	
	^ CheckImageInSyncWithUpdate ifNil: [CheckImageInSyncWithUpdate := true]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 6/12/2010 08:47'!
checkImageInSyncWithUpdate: aBoolean

	CheckImageInSyncWithUpdate := aBoolean! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:15'!
currentMajorVersionNumber

	^ CurrentMajorVersionNumber ! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:12'!
currentMajorVersionNumber: aNumber

	CurrentMajorVersionNumber := aNumber! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:06'!
currentlyIntegratingChanges

	CurrentlyIntegratingChanges isNil ifTrue: [self hideIntegrationMenu].
	^ CurrentlyIntegratingChanges! !

!ScriptLoader class methodsFor: 'private' stamp: 'adrian_lienhard 3/16/2009 21:32'!
defaultMCWaitingFolder
	"self defaultMCWaitingFolder" 
	
	^ MCDirectoryRepository new directory: self waitingCacheFolder! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			(self new)
				installGofer;
				gofer ]! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
hideIntegrationMenu

	CurrentlyIntegratingChanges := false.! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'MarcusDenker 4/24/2012 18:10'!
initialize
	self flag: #shouldRemoveNumber.
	CurrentMajorVersionNumber :=  2.0! !

!ScriptLoader class methodsFor: 'source' stamp: 'CamilloBruni 10/1/2012 12:52'!
latestSource: packageName location: location

  | contents versionName zip |
  
  versionName := location, '/', (self latestVersionOf: packageName location: location).
  contents := ZnClient new
		systemPolicy;
		setAcceptEncodingGzip;
		beOneShot;
		url: versionName;
		ifFail: [ :exception | self error: 'Cannot access latest source: ' , exception printString ];
		get.
    
  zip := ZipArchive new.
  zip readFrom: contents readStream.
  ^  (zip memberNamed: 'snapshot/source.st') contents.! !

!ScriptLoader class methodsFor: 'source' stamp: 'SeanDeNigris 8/26/2012 11:59'!
latestVersionOf: packageName location: location

  | repository sortMczs fileToLoad | 
  
  repository := MCHttpRepository location: location.
  sortMczs := [:a :b |
    [(a findBetweenSubStrs: #($.)) allButLast last asInteger > (b  
      findBetweenSubStrs: #($.)) allButLast last asInteger]
    on: Error do: [:ex | false]].
  
  fileToLoad := (repository readableFileNames asSortedCollection: sortMczs) detect: 
    [:file | file beginsWith: (packageName, '-')].
  
  ^ fileToLoad! !

!ScriptLoader class methodsFor: 'private' stamp: 'SeanDeNigris 8/26/2012 11:59'!
loadLatestPackage: aString from: aPath
	| repository |
	
	repository := MCHttpRepository location: aPath.
	self loadLatestPackage: aString fromRepository: repository! !

!ScriptLoader class methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
loadLatestPackage: aString fromRepository: aRepository
	| versionsBlock versions tries |
	
	versionsBlock := [ (aRepository allVersionNames select: [ :each |
		each beginsWith: aString ])
		asSortedCollection: [ :a :b |
			(a copyAfterLast: $.) asNumber <= (b copyAfterLast: $.) asNumber]].
	versions := versionsBlock value.
	tries := 0.
	[ versions isEmpty and: [ tries < 3 ] ] whileTrue: [
		versions := versionsBlock value.
		tries := tries + 1 ].
	versions isEmpty ifTrue: [ self error: 'problems when accessing squeaksource' ].
	
	aRepository versionReaderForFileNamed: (versions last , '.mcz') do: [:reader | | version |
		version := reader version.
		version load.
		version workingCopy repositoryGroup addRepository: aRepository]! !

!ScriptLoader class methodsFor: 'private' stamp: 'StephaneDucasse 8/21/2011 16:01'!
loadLatestPackage: aString fromSqueaksource: aDirectoryName
	" self loadLatestPackage: 'ScriptLoader' fromSqueaksource: 'Pharo' "

	self loadLatestPackage: aString from: self rootURLString, aDirectoryName
	! !

!ScriptLoader class methodsFor: 'menu' stamp: 'EstebanLorenzano 5/16/2012 16:47'!
menuCommandOn: aBuilder 
	<worldMenu>
	
	(aBuilder item: #'Integrator Menu')
		order: 1.5;
		precondition: [self currentlyIntegratingChanges];
		parent: #System;
		icon: self theme smallAuthoringToolsIcon;
		action: [ScriptLoader releaseMenu]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 11/9/2010 18:39'!
releaseMenu
	"self releaseMenu"
	|symbol|
	symbol := UIManager default
		chooseFrom: #('1- Prepare new update'
		                        '2- Save new image for testing (optional)'
						'3- Freeze changes: packages will be saved (required)'
						'4- Verify new update (open the mother image in the same folder) (optional)'
						'5- Publish changes')
		values: #(prepareNewUpdate saveImageForRunningTests doneApplyingChanges verifyNewUpdate publishChanges).
	symbol ifNotNil: [ScriptLoader new perform: symbol]! !

!ScriptLoader class methodsFor: 'public' stamp: 'adrian-lienhard 6/6/2009 11:46'!
resetLogStream
	LogStream := nil! !

!ScriptLoader class methodsFor: 'private' stamp: 'StephaneDucasse 8/21/2011 16:29'!
rootURLString 

	^ 'http://ss3.gemstone.com/ss/'! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
showIntegrationMenu

	CurrentlyIntegratingChanges := true.! !

!ScriptLoader class methodsFor: 'menu' stamp: 'FernandoOlivero 4/12/2011 10:14'!
theme
	^ UITheme current ! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'SeanDeNigris 7/12/2012 08:44'!
CSForLastUpdate: aString
	"ScriptLoader new CSForLastUpdate: 'cleanUpMethods'"
	
	| str updateNumber filename|
	updateNumber := self getLatestUpdateNumber.
	filename := updateNumber asString, '-Pha-', aString, '.cs'.
	filename asFileReference 
		delete;
		writeStreamDo: [ :stream|
			self 
				generateCS: self latestScriptLoaderPackageIdentificationString
				fromUpdate: updateNumber on: stream].
	^ filename! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 1/31/2010 22:31'!
CSForLastUpdateAndPatchUpdatesList: aString
	"ScriptLoader new CSForLastUpdateAndPatchUpdatesList: 'cleanUpMethods'"
	| filename |
	filename := self CSForLastUpdate: aString.
	self updateUpdatesList: aString.
	^ filename ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addExtraRepositories
	
	"self new addExtraRepositories"
	
	self addRepository39ToAllPackages.
	self addRepository310ToAllPackages.
	self addRepositoryTaskForcesToAllPackages.
	self addRepositorySqueakTrunkToAllPackages.
	self addRepositoryMCToAllPackages.
	self addRepositoryTreatedToAllPackages.! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 6/11/2012 17:03'!
addHomeRepositoryToAllPackages
	"self new addHomeRepositoryToAllPackages"
	
	self allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository;
			 addRepository: self inboxRepository ].
		
	MCRepositoryGroup default
			 addRepository: self repository;
			 addRepository: self inboxRepository.
	
		
	
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 17:40'!
addHomeRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 10/18/2009 16:11'!
addPackage: aString
	"to be tested" 
	
	| workingCopy |
	PackageInfo registerPackageName: aString.
	workingCopy := MCWorkingCopy forPackage: (MCPackage new name: aString)! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 5/26/2012 22:00'!
addRepository310ToAllPackages
	"self new addRepository310ToAllPackages"
	
	self allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository310
			].
	
	! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 5/26/2012 22:00'!
addRepository39ToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepository39ToAllPackages"
	
	self allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository39
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 5/26/2012 22:01'!
addRepositoryMCToAllPackages
	"self new addRepositoryMCToAllPackages"
	
	self allManagers do: [ :each | 
		each repositoryGroup  addRepository: self repositoryMC
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 5/26/2012 22:01'!
addRepositorySqueakTrunkToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepositorySqueakTrunkToAllPackages"
	
	self allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositorySqueakTrunk
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 5/26/2012 22:01'!
addRepositoryTaskForcesToAllPackages
	"self new addRepositoryTaskForcesToAllPackages"
	
	self allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTaskForces
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 10/31/2005 18:01'!
addRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 5/26/2012 22:01'!
addRepositoryTreatedToAllPackages
	"self new addRepositoryTreatedToAllPackages"
	
	self allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTreated
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentDirtyPackages
	"ScriptLoader new allCurrentDirtyPackages"
	"return all the current dirty packages even the ones that we do not want to save"

	
	^  self allCurrentPackages select: [:each | each needsSaving].

	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 5/26/2012 22:01'!
allCurrentPackages
	"ScriptLoader new allCurrentPackages" 
	
	| copies |
	copies := self allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 5/26/2012 21:57'!
allManagers

	^ MCWorkingCopy allManagers! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 10/16/2012 12:46'!
announceOnMailingList
	"self new announceOnMailingList"
	
	| title contents |
	title := '[update ', self currentMajorVersionNumber asString , '] #', self currentUpdateVersionNumber asString.
	
	contents := String streamContents: [:str |
			str 
				nextPutAll:  title; cr ; 
				nextPutAll: self currentUpdateVersionNumber asString; 
				nextPutAll: '
-----

';
				nextPutAll: self commentForCurrentUpdate.
			str cr.
			str nextPutAll: 'Diff information:'; cr.
			self produceDiffLinksForPackages do: [:each |
				str nextPutAll: each ; cr].
				 
			str contents
			].	
	
	UIManager default
		edit: contents
		label: title.! !

!ScriptLoader methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
buildConfigurationMapFor: packageNames

	| configurationMap |
	configurationMap := MCConfiguration new.
	configurationMap repositories
		add: self repository;
		add: self inboxRepository.

	packageNames do: [:packageName | | version depArray |
		version := self loadVersionFromFileNamed: packageName.
		depArray := { version package name. version info name. version info id asString. }.
		configurationMap dependencies add: (MCConfiguration dependencyFromArray: depArray)].
	^configurationMap! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'CamilloBruni 5/10/2012 15:58'!
checkImageIsUptodate
	^ self checkImageIsUptodateSilently
	! !

!ScriptLoader methodsFor: 'ci' stamp: 'CamilloBruni 5/10/2012 15:56'!
checkImageIsUptodateSilently

	| last number |
	self class checkImageInSyncWithUpdate 
		ifFalse: [^ true].	
	
	self updatesListFile writeStreamDo:  [ :stream |
		stream contents linesDo: [ :each | last := each ]].
	
	last isNil 
		ifTrue: [^ false]. "in case the file is empty"
	 (last copyUpTo: $-) isAllDigits
		ifFalse: [^ true].  			"for cases where we have #Pharo1.1rc1 starting the line"
	number := (last copyUpTo: $-) asNumber.
	^ number = self getLatestUpdateNumber.
! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 11/13/2010 22:31'!
cleanRepositories
	"self new cleanRepositories"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllRepositories.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'public' stamp: 'EstebanLorenzano 4/2/2013 13:02'!
commentForCurrentUpdate
 ^ 'Prepared for production.'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 14:36'!
compileNewUpdateMethod
	"Use me to create a new update method with the next update number"
	"self new compileNewUpdateMethod"
	

	self class compile: 
		(self newGenerateNewUpdateMethod)
		classified: 'pharo - updates'! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 20:13'!
compileNewUpdateMethodSilentlyPreLoad: preload postLoad: postLoad
	"Use me to create a new update method with the next update number"
	"self new compileNewUpdateMethod"
	

	self class compile: 
		(self newGenerateNewUpdateMethodSilentlyPreLoad: preload postLoad: postLoad)
		classified: 'pharo - updates'
! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 13:26'!
compileScriptMethodWithCurrentPackages: aNumber 
	"ScriptLoader new compileScriptMethodWithCurrentPackages: 9999"
	
	self class compile: 
		(self newGenerateScriptTemplateWithCurrentPackages: aNumber)
		classified: 'pharo - scripts'! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
copyPackagesFromWaitingFolderToHomeRepository
	"self defaultMCWaitingFolder allFileNames"
	"self new copyPackageFromWaitingFolderToHomeRepository"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		self repository storeVersion: version]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 5/26/2012 22:01'!
currentPackages
	"self new currentPackages" 
	
	
	| copies |
	copies := self allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies reject: [:each |
		self packagesNotToSavePatternNames
			anySatisfy: [:p | p match: each package name]].
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:08'!
currentScriptVersionNumber
	^ CurrentScriptVersionNumber! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 9/8/2009 14:41'!
currentUpdateVersionNumber
	^ CurrentUpdateVersionNumber ifNil: [SystemVersion current highestUpdate]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 5/26/2012 22:01'!
currentVersions
	"ScriptLoader new currentVersions"
	
	| copies |
	copies := self allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies collect:
		[:ea |  ea ancestry ancestorString ]! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'EstebanLorenzano 8/10/2012 18:35'!
deletePackage: aString
	| toRemove toUnregister | 
	
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	toRemove unload. 
	"With RPackage, each 'sub-package' is considered a separate package so we need to also unregister them"
	toUnregister := RPackageOrganizer default packages select: [:each | (each name = aString) or:  [each name beginsWith: aString,'-']].
	RPackageOrganizer default unregisterPackageNamed: aString.
! !

!ScriptLoader methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 10/16/2012 12:40'!
diffServerRootString

	^  'http://ss3.gemstone.com/ss/Pharo20/'! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'MarcusDenker 7/10/2012 10:36'!
doneApplyingChanges
	| comment commentQuoted st |
	Smalltalk image saveSession.
		"now you can reopen prior to publishing to fix :)"
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	
	comment := UIManager default
		multiLineRequest: 'Comment for this update.'
		initialAnswer: self commentForCurrentUpdate
		answerHeight: 200.
	comment ifNil: [^ self].
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteAllChildren.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersion.
	self saveLatestScriptLoaderToWaitingFolder.
	
	self inform: 'Update prepared and ready to be verified.'! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 7/10/2012 10:37'!
doneApplyingChangesSilentlyComment: providedComment preLoad: preload postLoad: postLoad
	| comment commentQuoted st |
	Smalltalk image saveSession.
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	comment := providedComment trimBoth.
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteAllChildren.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersionSilentlyPreLoad: preload postLoad: postLoad.
	self saveLatestScriptLoaderToWaitingFolder.! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 7/10/2012 10:37'!
doneApplyingChangesSilentlyIssues: issuesToIntegrate preLoad: preload postLoad: postLoad
	| comment commentQuoted st |
	Smalltalk image saveSession.
		"now you can reopen prior to publishing to fix :)"
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	comment := String streamContents: [:stream |
		issuesToIntegrate do: [:each | 
			stream << each name << 'Thanks to ' << each content author email ; lf;lf.
			stream << each url;lf;lf;lf.]].
	comment := comment trimBoth.
	
	"comment := UIManager default
		multiLineRequest: 'Comment for this update.'
		initialAnswer: self commentForCurrentUpdate
		answerHeight: 200.
	comment ifNil: [^ self]."
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteAllChildren.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersionSilentlyPreLoad: preload postLoad: postLoad.
	self saveLatestScriptLoaderToWaitingFolder.
! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 3/14/2010 12:44'!
flushCaches

	MCFileBasedRepository flushAllCaches.
	MCDefinition clearInstances.
	Smalltalk garbageCollect.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 8/21/2011 16:24'!
generateCS: packageInfo fromUpdate: updateNumber on: st
	
	st nextPutAll:
'"Postscript:
Leave the line above, and replace the rest of this comment by a useful one.
Executable statements should follow this comment, and should
be separated by periods, with no exclamation points (!!!!).
Be sure to put any further comments in double-quotes, like this one."

|repository|
repository := MCHttpRepository
                location: ''', self homeRepositoryUrlString,
'''
                user: ''''
                password: ''''.
(repository loadVersionFromFileNamed:' .
	st nextPut: $' ; nextPutAll: packageInfo, '.mcz'') load.'; cr.
	st nextPutAll: 'ScriptLoader new update', (updateNumber) asString; nextPutAll: '.' ; cr.
	st nextPutAll: '!!'.
	^ st contents
! !

!ScriptLoader methodsFor: 'utils' stamp: 'stephane.ducasse 7/4/2009 12:27'!
generateCompleteFixList
	"generateCompleteFixList"
	| stream |
	stream := (FileStream newFileNamed: 'changes-log.txt').
	[ stream nextPutAll: ScriptLoader new logStream contents ] ensure: [ stream close ]! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 9/7/2011 22:03'!
generateNewUpdateMethod
	"ScriptLoader new generateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, '.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'adrianLienhard 11/1/2008 23:05'!
generateScriptAndUpdateMethodForNewVersion
	"Use me to generate the script and update method"
	"self new generateScriptAndUpdateMethodForNewVersion"
	
	self compileScriptMethodWithCurrentPackages: self currentScriptVersionNumber.
	self compileNewUpdateMethod.! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 20:12'!
generateScriptAndUpdateMethodForNewVersionSilentlyPreLoad: preload postLoad: postLoad
	"Use me to generate the script and update method"
	"self new generateScriptAndUpdateMethodForNewVersion"
	
	self compileScriptMethodWithCurrentPackages: self currentScriptVersionNumber.
	self compileNewUpdateMethodSilentlyPreLoad: preload postLoad: postLoad.
! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 14:41'!
generateScriptTemplateWithAllCurrentPackages
	"ScriptLoader new generateScriptTemplateWithAllCurrentPackages"
	
	| str |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'scriptXXX' ; cr ; cr ; tab.
	str nextPutAll: '| names|'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	self currentVersionsToBeSaved do: 
		[:each |
			str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 18:07'!
generateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '| names |'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'al 11/1/2008 18:15'!
getLatestScriptNumber
	"self new getLatestScriptNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'script*' match: each ].
	upfroms := upfroms collect: [:each | (each asString allButFirst: 6)].
	upfroms := upfroms reject: [:each | '*Log*' match: each ].
	upfroms := upfroms reject: [:each | '*XXX*' match: each ].
	upfroms := upfroms collect: [:each | each asNumber].
	^ upfroms asSortedCollection last
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'sd 4/20/2012 16:16'!
getLatestUpdateNumber
	"self new getLatestUpdateNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'update*' match: each ].
	upfroms := upfroms collect: [:each | [(each asString last: 5) asNumber] on: Error do: [0]].
	^ upfroms asSortedCollection last! !

!ScriptLoader methodsFor: 'accessing' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			self
				installGofer;
				gofer ]! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'MarcusDenker 4/19/2012 16:58'!
homeRepositoryUrlString
	
	^ self rootURLString, 'Pharo20'! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 8/21/2011 15:23'!
inboxRepository
	^ inboxRepository ifNil: [inboxRepository :=  self inboxRepositoryDefault]
	! !

!ScriptLoader methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 8/21/2011 15:23'!
inboxRepositoryDefault
	^ MCHttpRepository new 
	 	location: self inboxRepositoryUrlString;
		user: '';
		password: ''! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 8/21/2011 15:50'!
inboxRepositoryUrlString
	
	^ self rootURLString, 'PharoInbox'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'SeanDeNigris 8/26/2012 15:54'!
installRepository: aString for: packageName

	(self allManagers select: [:each | each package name = packageName])
		first repositoryGroup
		addRepository: (MCHttpRepository location: aString)
		! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'alain.plantec 2/6/2009 15:49'!
installVersionInfo
	"self new installVersionInfo"

	| highestUpdate newVersion |
	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := UIManager default request: 'New version designation:' translated initialAnswer: '3.9' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	
! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 8/14/2008 16:03'!
latestScriptLoaderPackageIdentificationString
	"ScriptLoader new latestScriptLoaderPackageIdentificationString"
	
	^  self allCurrentVersions detect: [:each | 'ScriptLoader*' match: each ]
	! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'Jb 10/23/2010 12:14'!
launchUpdate

	UpdateStreamer new updateFromServer! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 18:04'!
launchUpdateSilently

	^ UpdateStreamer new updateFromServerSilently
! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'MarcusDenker 4/19/2012 17:33'!
loadLatestScriptloader
	"self new loadLatestScriptloader"
	
	self class 
		loadLatestPackage: 'ScriptLoader', self currentMajorVersionNumberWithoutDot 
		fromSqueaksource: 'Pharo20' 
	

! !

!ScriptLoader methodsFor: 'private' stamp: 'CamilloBruni 10/1/2012 12:52'!
loadLatestUpdateList
	"fetch the latest version of the update.list on the server"
	
	| result listToUse lastUpdate |
	result := ZnClient new
		systemPolicy;
		beOneShot;
		setAcceptEncodingGzip;
		accept: ZnMimeType text;
		url: (UpdateStreamer new updateFolderURL, self updatesListFileName);
		ifFail: [ :exception | self error: 'Cannot access update server: ' , exception printString ];
		get.
	(listToUse := result lines) isEmpty 
		ifTrue: [ self error: 'Update list is empty' ].			
	lastUpdate := listToUse last.
	(lastUpdate beginsWith: self getLatestUpdateNumber asString)
		 ifTrue: ["Write this file as our current updates.list"
			self updatesListFileName asFileReference
				delete;
				writeStreamDo: [:stream | stream nextPutAll: result ] ]
		ifFalse: [ 
			self inform: 'Image update version did not match automatically fetched  update.list!!  
			Proceed after downloading using the script ./getUpdatesList instead' ].
	! !

!ScriptLoader methodsFor: 'ci' stamp: 'SeanDeNigris 7/12/2012 08:44'!
loadLatestUpdateListSilently
	"fetch the latest version of the update.list on the server"
	
	| result listToUse lastUpdate |
	(result := ZnEasy get: UpdateStreamer new updateFolderURL, self updatesListFileName) isSuccess
		ifFalse: [ self error: 'Cannot access update server' ].
	listToUse := result contents.			
	listToUse linesDo: [:each | lastUpdate := each].
	(lastUpdate beginsWith: self getLatestUpdateNumber asString)
		 ifTrue: ["Write this file as our current updates.list"
			self updatesListFileName asFileReference delete;
				writeStreamDo:  [:stream | stream nextPutAll: listToUse]]
		ifFalse: [ 
			self inform: 'Image update version did not match automatically fetched  update.list!!  
			Proceed after downloading using the script ./getUpdatesList instead' ].
	! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'StephaneDucasse 12/14/2011 21:46'!
loadOneAfterTheOther: aCollection merge: aBoolean
	
	(self newerVersionsIn: aCollection)
		do: [:fn | | loader |
			loader := aBoolean
				ifTrue: [ MCVersionMerger new ]
				ifFalse: [ MCVersionLoader new].
			loader addVersion: (self repository loadVersionFromFileNamed: fn).
			aBoolean
				ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
							request merger conflicts isEmpty
								ifTrue: [request resume: true]
								ifFalse: [request pass]]]
				ifFalse: [loader load]].
	

! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
loadPackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		version load]! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'michael.rueger 1/13/2009 15:26'!
loadTogether: aCollection merge: aBoolean
	| loader |
	loader := aBoolean
		ifTrue: [ MCVersionMerger new ]
		ifFalse: [ MCVersionLoader new].
	(self newerVersionsIn: aCollection)
		do: [:fn | loader addVersion: (self loadVersionFromFileNamed: fn)]
  	  	displayingProgress: 'Adding versions...'.
	aBoolean
		ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
					request merger conflicts isEmpty
						ifTrue: [request resume: true]
						ifFalse: [request pass]]]
		ifFalse: [loader hasVersions ifTrue: [loader load]]

! !

!ScriptLoader methodsFor: 'private' stamp: 'michael.rueger 1/13/2009 15:25'!
loadVersionFromFileNamed: fn
	| version |
	version := self repository loadVersionFromFileNamed: fn.
	^version
		ifNil: [self inboxRepository loadVersionFromFileNamed: fn]! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 4/4/2008 14:47'!
log: aString

	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/15/2008 18:30'!
logContents

	^ self logStream contents! !

!ScriptLoader methodsFor: 'log' stamp: 'adrian_lienhard 3/16/2009 21:30'!
logStream
	^ LogStream ifNil: [
		LogStream := ReadWriteStream on: (String new: 1000)]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
mergePackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles
		do: [ :name | | version |
			version := self class defaultMCWaitingFolder  versionFromFileNamed: name.
			version merge.
			]! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 9/7/2011 22:03'!
newGenerateNewUpdateMethod
	"ScriptLoader new newGenerateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self loadTogether: '.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, ' merge: false.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'ci' stamp: 'MarcusDenker 2/28/2012 20:13'!
newGenerateNewUpdateMethodSilentlyPreLoad: preload postLoad: postLoad
	"ScriptLoader new newGenerateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := preload reset contents asString.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab ].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self loadTogether: '.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, ' merge: false.'.
	str crtab.
	postscript := postLoad reset contents asString. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab ].
	
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:25'!
newGenerateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	"this version change the script to only "
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '^ '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr'.
	^ str contents! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'StephaneDucasse 5/26/2012 22:02'!
newerVersionsIn: aCollection
	^aCollection reject: [:each |
		self allManagers anySatisfy: [:workingcopy |
			workingcopy ancestry ancestorString , '.mcz' = each]].! !

!ScriptLoader methodsFor: 'utils' stamp: 'sd 2/4/2008 16:09'!
openWindow: contents label: aLabel

	StringHolder new 
		contents: contents ;
		openLabel: aLabel! !

!ScriptLoader methodsFor: 'private' stamp: 'MarcusDenker 10/21/2012 11:07'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'SLICE*'
			'Slice*'
			'slice*'
			'ConfigurationOf*'
		).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'CamilloBruni 5/7/2012 02:08'!
prepareNewUpdate
	self launchUpdate.
	self loadLatestScriptloader.
	self markPackagesBeforeNewCodeIsLoaded.
	self checkImageIsUptodate ifFalse: [self loadLatestUpdateList].
	self checkImageIsUptodate ifFalse: [
		^ self inform: 'Your update.list and your image are not in sync!! Please use a fresh image and download the latest update.list and start over. May be you are doing a rollback and you should remove the bogus ScriptLoader version from the Pharo repository' ].
	self setUpdateAndScriptVersionNumbers.
	self saveAsNewImageWithCurrentReleaseName.
	self inform: 'The new version number is ' , self currentUpdateVersionNumber asString , '. Ready to apply changes now.', String cr, 'You are now running in image ', (Smalltalk imageFile basename).! !

!ScriptLoader methodsFor: 'ci' stamp: 'sd 4/20/2012 16:06'!
prepareNewUpdateSilently
	"Return nil on error"

	self launchUpdateSilently ifFalse: [ ^ nil ].
	[ self loadLatestScriptloader ]
		on: Warning
		do: [:warning | ^ nil ].
	self markPackagesBeforeNewCodeIsLoaded.
	self checkImageIsUptodateSilently ifFalse: [ self loadLatestUpdateListSilently ].
	self checkImageIsUptodate ifFalse: [ ^ nil ].
	self setUpdateAndScriptVersionNumbers.
	self saveAsNewImageWithCurrentReleaseName.
	^ self currentUpdateVersionNumber! !

!ScriptLoader methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 10/16/2012 12:45'!
produceDiffLinksForPackages
	"self defaultMCWaitingFolder allFileNames"
	"self new produceDiffLinksForPackages"
	
	| filenames |
	filenames := self waitingFolderMCZFiles.
	filenames := filenames reject: [:each | 'ScriptLoader*' match: each ].
	^ filenames collect: [:name |
			|diff |
			diff := name copyUpToLast: $. .
			diff := self diffServerRootString, diff, '.diff'
		]
		! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 1/31/2011 22:17'!
publishChanges
	| username password changescriptname changesetFilename str strings|
	(FileStream isAFileNamed: 'PharoPass.txt') 
		ifTrue: [ str := FileStream fileNamed:  'PharoPass.txt'. 
				strings := str contents substrings.
				username := strings first.
				password := strings second] 
		ifFalse: [ username := UIManager default request: 'Pharo repository login'.
			     password := UIManager default requestPassword: 'Pharo repository password'.].

	self setToRepositoriesPassword: password to: username.
	
	changescriptname := UIManager default request: 'Changeset name (no space)' initialAnswer: 'WhatAsChanged'.
	changesetFilename := self CSForLastUpdateAndPatchUpdatesList: changescriptname.
	self copyPackagesFromWaitingFolderToHomeRepository.
	self announceOnMailingList.
	self inform: 'All packages have been uploaded to the Pharo repository.
Remaining manual steps:
1) ./upFilesXX ',changesetFilename,'
2) ./upFilesXX updatesXX.list
3) Announce new update on mailing list'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 5/26/2012 22:02'!
removeAllHTTPRepositories: aColl
	"self new removeAllRepositories: 
			#('http://source.squeakfoundation.org/inbox/'
			 'http://source.squeakfoundation.org/39a/'
			 'http://source.squeakfoundation.org/Balloon/'
			 'http://source.squeakfoundation.org/Compression/'
			 'http://source.squeakfoundation.org/Graphics/'
			  'http://source.wiresong.ca/mc/')"
 
	self allManagers do: [:each | 
		aColl do: [ :location | 
					each  repositoryGroup removeHTTPRepositoryLocationNamed: location]].
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 5/26/2012 22:02'!
removeAllRepositories
	"self new removeAllRepositories"
	
	self allManagers do: [:each |  each  repositoryGroup initialize].
	MCRepositoryGroup default initialize.
	! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:06'!
removeScriptMethods
	"self new removeScriptMethods"
	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - scripts') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'utils' stamp: 'MarcusDenker 3/4/2013 14:31'!
removeUpdateMethods
	"self new removeUpdateMethods"
	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - updates') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 8/21/2011 15:19'!
repository
	^ repository ifNil: [
		repository := MCHttpRepository new
			location: self homeRepositoryUrlString ;
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'SeanDeNigris 8/26/2012 15:55'!
repository310
	^ repository310 ifNil: [
		repository310 := MCHttpRepository location: 'http://source.squeakfoundation.org/310']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'SeanDeNigris 8/26/2012 15:55'!
repository39
	^ repository39 ifNil: [
		repository39 := MCHttpRepository location:  'http://source.squeakfoundation.org/39a']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:42'!
repository: aRepository
	repository := aRepository! !

!ScriptLoader methodsFor: 'accessing' stamp: 'SeanDeNigris 8/26/2012 15:55'!
repositoryMC
	^ repositoryMC ifNil: [
		repositoryMC := MCHttpRepository location: 'http://source.wiresong.ca/mc']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'SeanDeNigris 8/26/2012 15:55'!
repositorySqueakTrunk
	^ repositorySqueakTrunk ifNil: [
		repositorySqueakTrunk := MCHttpRepository location: 'http://source.squeakfoundation.org/trunk']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'SeanDeNigris 8/26/2012 15:56'!
repositoryTaskForces
	^ repositoryTaskForces ifNil: [
		repositoryTaskForces := MCHttpRepository location: self taskForcesRepositoryUrlString]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'SeanDeNigris 8/26/2012 15:56'!
repositoryTreated
	^ repositoryTreated ifNil: [
		repositoryTreated := MCHttpRepository location:  'http://www.squeaksource.com/PharoTreatedInbox']! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 8/21/2011 16:30'!
rootURLString 

	^ self class rootURLString! !

!ScriptLoader methodsFor: 'private' stamp: 'MarcusDenker 7/10/2012 10:37'!
saveAsImageAsTestImage
	"Now you can run tests and see and go back to the previous image
	and do that go and back.... then after you can decide to freeze"

	| file |
	file := FileSystem workingDirectory  /  (self shortImageName, '-imageForTests') , Smalltalk imageSuffix.
	Smalltalk image saveAs: file nextVersion basename.! !

!ScriptLoader methodsFor: 'private' stamp: 'MarcusDenker 7/10/2012 10:37'!
saveAsNewImageWithCurrentReleaseName
	| file |
	file := FileSystem workingDirectory  / (('Pharo-', self currentUpdateVersionNumber asString), '-Release'), Smalltalk imageSuffix.
	Smalltalk image saveAs: (file nextVersion basename copyUpToLast: Path extensionDelimiter). ! !

!ScriptLoader methodsFor: 'private' stamp: 'MarcusDenker 7/10/2012 10:37'!
saveAsNewImageWithCurrentReleaseNameToPublish
	"If the reload failed and you do not want to lose time reload all the cs and packages... you can now restart from the image saved now"
	
	| file |
	file := FileSystem workingDirectory  / (self shortImageName, '-releasePharoToPublish'), Smalltalk imageSuffix.
	
	Smalltalk image saveAs: file nextVersion basename.! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'al 11/1/2008 18:33'!
saveChangedPackagesIntoWaitingFolder
	self currentChangedPackages do: [:each |
		self
			saveInToReloadCachePackage: each
			with: self commentForCurrentUpdate]! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'MarcusDenker 7/10/2012 10:37'!
saveImageForRunningTests

	| comment commentQuoted st resuming |
	resuming := false.
	Smalltalk image saveSession
		ifFalse: [ resuming := true].
	resuming ifTrue: [
		self saveAsImageAsTestImage.
	
		self inform: 'Now you can use this image named ''Test'' to run the tests and come back to fix problems in the \ previous one and eventually freeze it by selecting the next step, in either one.' withCRs]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'adrianLienhard 11/2/2008 00:31'!
saveInToReloadCachePackage: aWorkingCopy with: aMessageString
	self
		savePackage: aWorkingCopy
		in: self class defaultMCWaitingFolder
		with: aMessageString! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 5/26/2012 22:02'!
saveLatestScriptLoaderToHome
	"self new saveLatestScriptLoaderToHome"

	| man r |
	man := self allManagers.
	r := man select: [:each | 'ScriptLoader*' match: each  package name].
	self repository storeVersion: r first newVersion.! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 5/26/2012 22:02'!
saveLatestScriptLoaderToWaitingFolder
	"self new saveLatestScriptLoaderToWaitingFolder"

	| man r |
	man := self allManagers.
	r := man select: [:each | 'ScriptLoader', self currentMajorVersionNumberWithoutDot, '*' match: each  package name].
	self
		saveInToReloadCachePackage: r first
		with: self commentForCurrentUpdate! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'SeanDeNigris 7/17/2012 15:50'!
savePackage: aWorkingCopy in: aRepository with: aMessageString
	" | sc |
	  sc := self new.
	  sc savePackage: (self new workingCopyFromPackageName: 'ScriptLoader11') 
		in: MCCacheRepository uniqueInstance
		with: 'this is test to automate dirty package saving in cache'"

	aRepository storeVersion: (aWorkingCopy 
		newVersionWithName: aWorkingCopy uniqueVersionName
		message: aMessageString)! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'EstebanLorenzano 3/7/2013 15:46'!
script562

	^ 'AST-Core-MarcusDenker.113.mcz
AST-Semantic-StephaneDucasse.21.mcz
AST-Tests-Core-MarcusDenker.21.mcz
AST-Tests-Semantic-StephaneDucasse.5.mcz
AndreasProfiler-EstebanLorenzano.5.mcz
Announcements-Core-MarcusDenker.37.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-MarcusDenker.13.mcz
AsmJit-Core-CamilloBruni.2.mcz
AsmJit-Extension-StephaneDucasse.6.mcz
AsmJit-Instructions-CamilloBruni.3.mcz
AsmJit-Operands-CamilloBruni.3.mcz
AsmJit-StackManagement-CamilloBruni.2.mcz
AsmJit-x86-IgorStasenko.3.mcz
Balloon-MarcusDenker.91.mcz
BalloonTests-MarcusDenker.1.mcz
CI-Core-EstebanLorenzano.66.mcz
CI-Loader-MarcusDenker.1.mcz
CodeImport-MarcusDenker.12.mcz
CodeImport-Tests-MarcusDenker.8.mcz
Collections-Abstract-MarcusDenker.199.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-EstebanLorenzano.69.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.6.mcz
Collections-Sequenceable-EstebanLorenzano.130.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.131.mcz
Collections-Strings-MarcusDenker.240.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-EstebanLorenzano.82.mcz
Collections-Traits-MarcusDenker.13.mcz
Collections-Unordered-MarcusDenker.147.mcz
Collections-Weak-MarcusDenker.68.mcz
CollectionsTests-MarcusDenker.583.mcz
Compatibility-MarcusDenker.10.mcz
Compiler-EstebanLorenzano.379.mcz
CompilerTests-MarcusDenker.131.mcz
Compression-MarcusDenker.122.mcz
CompressionTests-MarcusDenker.21.mcz
ConfigurationCommandLineHandler-Core-MarcusDenker.8.mcz
ConfigurationCommandLineHandler-Tests-MarcusDenker.2.mcz
Deprecated20-MarcusDenker.32.mcz
EmergencyEvaluator-MarcusDenker.28.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-EstebanLorenzano.15.mcz
FileSystem-AnsiStreams-MarcusDenker.7.mcz
FileSystem-Core-MarcusDenker.63.mcz
FileSystem-Disk-MarcusDenker.48.mcz
FileSystem-Memory-MarcusDenker.20.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.6.mcz
FileSystem-Tests-Core-MarcusDenker.39.mcz
FileSystem-Tests-Disk-MarcusDenker.13.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-EstebanLorenzano.ducasse.294.mcz
FreeType-MarcusDenker.612.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Fuel-EstebanLorenzano.762.mcz
FuelCommandLineHandler-EstebanLorenzano.21.mcz
FuelSystem-FileRegistry-EstebanLorenzano.3.mcz
FuelTests-MaxLeske.311.mcz
FuelTools-Debugger-EstebanLorenzano.2.mcz
Gofer-Core-MarcusDenker.191.mcz
Gofer-Tests-MarcusDenker.157.mcz
Graphics-Display Objects-MarcusDenker.104.mcz
Graphics-Files-MarcusDenker.39.mcz
Graphics-Fonts-MarcusDenker.67.mcz
Graphics-Primitives-StephaneDucasse.99.mcz
Graphics-Resources-StephaneDucasse.16.mcz
Graphics-Tests-StephaneDucasse.30.mcz
Graphics-Transformations-StephaneDucasse.7.mcz
GroupManager-EstebanLorenzano.39.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-MarcusDenker.13.mcz
HelpSystem-Core-StephaneDucasse.89.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-MarcusDenker.16.mcz
HudsonBuildTools20-EstebanLorenzano.25.mcz
Kernel-EstebanLorenzano.1332.mcz
KernelTests-EstebanLorenzano.476.mcz
KeyChain-StephaneDucasse.29.mcz
Keymapping-Core-EstebanLorenzano.142.mcz
Keymapping-Pragmas-MarcusDenker.39.mcz
Keymapping-Settings-MarcusDenker.65.mcz
Keymapping-Shortcuts-EstebanLorenzano.65.mcz
Keymapping-Tests-MarcusDenker.69.mcz
Keymapping-Tools-Spec-MarcusDenker.16.mcz
Manifest-Core-MarcusDenker.111.mcz
Manifest-CriticBrowser-MarcusDenker.62.mcz
Manifest-Resources-Tests-EstebanLorenzano.9.mcz
Manifest-Tests-MarcusDenker.26.mcz
MenuRegistration-EstebanLorenzano.47.mcz
Metacello-Base-MarcusDenker.20.mcz
Metacello-Core-MarcusDenker.494.mcz
Metacello-MC-StephaneDucasse.666.mcz
Metacello-Platform.pharo20-MarcusDenker.29.mcz
Metacello-ToolBox-MarcusDenker.135.mcz
Monticello-MarcusDenker.775.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.213.mcz
MonticelloMocks-EstebanLorenzano.2.mcz
Morphic-EstebanLorenzano.1369.mcz
MorphicTests-MarcusDenker.67.mcz
Multilingual-Encodings-MarcusDenker.39.mcz
Multilingual-Languages-MarcusDenker.30.mcz
Multilingual-Tests-MarcusDenker.25.mcz
Multilingual-TextConversion-MarcusDenker.46.mcz
NECompletion-MarcusDenker.99.mcz
NOCompletion-MarcusDenker.34.mcz
NativeBoost-Core-EstebanLorenzano.116.mcz
NativeBoost-Examples-EstebanLorenzano.16.mcz
NativeBoost-Mac-IgorStasenko.8.mcz
NativeBoost-Pools-IgorStasenko.12.mcz
NativeBoost-Unix-IgorStasenko.12.mcz
NativeBoost-Win32-EstebanLorenzano.35.mcz
Nautilus-MarcusDenker.434.mcz
NautilusCommon-MarcusDenker.120.mcz
NautilusRefactoring-MarcusDenker.78.mcz
Network-Kernel-MarcusDenker.85.mcz
Network-MIME-MarcusDenker.52.mcz
Network-Mail-StephaneDucasse.14.mcz
Network-Protocols-MarcusDenker.88.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-URI-MarcusDenker.41.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-MarcusDenker.84.mcz
NetworkTests-MarcusDenker.79.mcz
NewClassOrganizer-MarcusDenker.7.mcz
NewList-MarcusDenker.24.mcz
NonInteractiveTranscript-MarcusDenker.5.mcz
PackageInfo-MarcusDenker.91.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.86.mcz
Polymorph-Widgets-MarcusDenker.775.mcz
RPackage-Core-EstebanLorenzano.214.mcz
RPackage-SystemIntegration-EstebanLorenzano.162.mcz
RPackage-Tests-MarcusDenker.109.mcz
RecentSubmissions-EstebanLorenzano.180.mcz
Refactoring-Changes-MarcusDenker.35.mcz
Refactoring-Core-MarcusDenker.169.mcz
Refactoring-Critics-MarcusDenker.30.mcz
Refactoring-Environment-StephaneDucasse.12.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-MarcusDenker.38.mcz
Refactoring-Tests-Changes-StephaneDucasse.18.mcz
Refactoring-Tests-Core-StephaneDucasse.63.mcz
Refactoring-Tests-Critics-MarcusDenker.8.mcz
Refactoring-Tests-Environment-StephaneDucasse.5.mcz
Regex-Core-MarcusDenker.22.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.19.mcz
Ring-Core-Kernel-MarcusDenker.90.mcz
Ring-Monticello-StephaneDucasse.12.mcz
Ring-Tests-Containers-MarcusDenker.9.mcz
Ring-Tests-Kernel-MarcusDenker.44.mcz
Ring-Tests-Monticello-MarcusDenker.10.mcz
SUnit-Core-MarcusDenker.66.mcz
SUnit-Help-MarcusDenker.4.mcz
SUnit-Tests-MarcusDenker.21.mcz
SUnit-UI-MarcusDenker.60.mcz
SUnit-UITesting-MarcusDenker.4.mcz
SUnit-Utilities-EstebanLorenzano.10.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.9.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.3.mcz
Settings-Monticello-MarcusDenker.6.mcz
Settings-Network-StephaneDucasse.16.mcz
Settings-Polymorph-StephaneDucasse.45.mcz
Settings-System-MarcusDenker.23.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-StephaneDucasse.158.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-StephaneDucasse.22.mcz
Spec-Builder-MarcusDenker.21.mcz
Spec-Core-MarcusDenker.88.mcz
Spec-Examples-EstebanLorenzano.18.mcz
Spec-Layout-MarcusDenker.27.mcz
Spec-Tests-EstebanLorenzano.21.mcz
Spec-Tools-MarcusDenker.89.mcz
Spec-Widgets-MarcusDenker.106.mcz
StartupPreferences-MarcusDenker.77.mcz
System-Announcements-MarcusDenker.41.mcz
System-Applications-MarcusDenker.44.mcz
System-Changes-EstebanLorenzano.198.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.79.mcz
System-FilePackage-MarcusDenker.72.mcz
System-FileRegistry-MarcusDenker.24.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-MarcusDenker.20.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.26.mcz
System-Localization-MarcusDenker.67.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Platforms-MarcusDenker.27.mcz
System-PragmaCollector-MarcusDenker.11.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.271.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.796.mcz
System-Text-EstebanLorenzano.216.mcz
System-Tools-StephaneDucasse.93.mcz
SystemProgress-MarcusDenker.5.mcz
Tests-MarcusDenker.522.mcz
Text-EstebanLorenzano.52.mcz
TextTests-MarcusDenker.3.mcz
Tools-MarcusDenker.1058.mcz
ToolsTest-MarcusDenker.denker.30.mcz
Traits-MarcusDenker.462.mcz
Transcript-MarcusDenker.6.mcz
UI-MarcusDenker.5.mcz
UIManager-MarcusDenker.98.mcz
Unicode-Initialization-MarcusDenker.4.mcz
UpdateStreamer-Core-MarcusDenker.12.mcz
UpdateStreamer-Tests-MarcusDenker.2.mcz
Zinc-Character-Encoding-Core-SvenVanCaekenberghe.5.mcz
Zinc-Character-Encoding-Tests-SvenVanCaekenberghe.3.mcz
Zinc-FileSystem-SvenVanCaekenberghe.9.mcz
Zinc-HTTP-EstebanLorenzano.346.mcz
Zinc-Patch-HTTPSocket-MarcusDenker.4.mcz
Zinc-Resource-Meta-Core-EstebanLorenzano.11.mcz
Zinc-Resource-Meta-FileSystem-MarcusDenker.3.mcz
Zinc-Resource-Meta-Tests-EstebanLorenzano.8.mcz
Zinc-System-Support-MarcusDenker.4.mcz
Zinc-Tests-SvenVanCaekenberghe.176.mcz
Zinc-Zodiac-EstebanLorenzano.26.mcz
Zodiac-Core-SvenVanCaekenberghe.27.mcz
Zodiac-Extra-NorbertHartl.6.mcz
Zodiac-Tests-SvenVanCaekenberghe.10.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'EstebanLorenzano 3/8/2013 15:08'!
script563

	^ 'AST-Core-MarcusDenker.113.mcz
AST-Semantic-StephaneDucasse.21.mcz
AST-Tests-Core-MarcusDenker.21.mcz
AST-Tests-Semantic-StephaneDucasse.5.mcz
AndreasProfiler-EstebanLorenzano.5.mcz
Announcements-Core-MarcusDenker.37.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-MarcusDenker.13.mcz
AsmJit-Core-CamilloBruni.2.mcz
AsmJit-Extension-StephaneDucasse.6.mcz
AsmJit-Instructions-CamilloBruni.3.mcz
AsmJit-Operands-CamilloBruni.3.mcz
AsmJit-StackManagement-CamilloBruni.2.mcz
AsmJit-x86-IgorStasenko.3.mcz
Balloon-MarcusDenker.91.mcz
BalloonTests-MarcusDenker.1.mcz
CI-Core-EstebanLorenzano.66.mcz
CI-Loader-MarcusDenker.1.mcz
CodeImport-MarcusDenker.12.mcz
CodeImport-Tests-MarcusDenker.8.mcz
Collections-Abstract-MarcusDenker.199.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-EstebanLorenzano.69.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.6.mcz
Collections-Sequenceable-EstebanLorenzano.130.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.131.mcz
Collections-Strings-MarcusDenker.240.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-EstebanLorenzano.82.mcz
Collections-Traits-MarcusDenker.13.mcz
Collections-Unordered-MarcusDenker.147.mcz
Collections-Weak-MarcusDenker.68.mcz
CollectionsTests-MarcusDenker.583.mcz
Compatibility-MarcusDenker.10.mcz
Compiler-EstebanLorenzano.379.mcz
CompilerTests-MarcusDenker.131.mcz
Compression-MarcusDenker.122.mcz
CompressionTests-MarcusDenker.21.mcz
ConfigurationCommandLineHandler-Core-MarcusDenker.8.mcz
ConfigurationCommandLineHandler-Tests-MarcusDenker.2.mcz
Deprecated20-MarcusDenker.32.mcz
EmergencyEvaluator-MarcusDenker.28.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-EstebanLorenzano.15.mcz
FileSystem-AnsiStreams-MarcusDenker.7.mcz
FileSystem-Core-MarcusDenker.63.mcz
FileSystem-Disk-MarcusDenker.48.mcz
FileSystem-Memory-MarcusDenker.20.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.6.mcz
FileSystem-Tests-Core-MarcusDenker.39.mcz
FileSystem-Tests-Disk-MarcusDenker.13.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-EstebanLorenzano.ducasse.294.mcz
FreeType-MarcusDenker.612.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Fuel-EstebanLorenzano.762.mcz
FuelCommandLineHandler-EstebanLorenzano.21.mcz
FuelSystem-FileRegistry-EstebanLorenzano.3.mcz
FuelTests-MaxLeske.311.mcz
FuelTools-Debugger-EstebanLorenzano.2.mcz
Gofer-Core-MarcusDenker.191.mcz
Gofer-Tests-MarcusDenker.157.mcz
Graphics-Display Objects-MarcusDenker.104.mcz
Graphics-Files-MarcusDenker.39.mcz
Graphics-Fonts-MarcusDenker.67.mcz
Graphics-Primitives-StephaneDucasse.99.mcz
Graphics-Resources-StephaneDucasse.16.mcz
Graphics-Tests-StephaneDucasse.30.mcz
Graphics-Transformations-StephaneDucasse.7.mcz
GroupManager-EstebanLorenzano.39.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-MarcusDenker.13.mcz
HelpSystem-Core-StephaneDucasse.89.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-MarcusDenker.16.mcz
HudsonBuildTools20-EstebanLorenzano.25.mcz
Kernel-EstebanLorenzano.1337.mcz
KernelTests-EstebanLorenzano.476.mcz
KeyChain-StephaneDucasse.29.mcz
Keymapping-Core-EstebanLorenzano.142.mcz
Keymapping-Pragmas-MarcusDenker.39.mcz
Keymapping-Settings-MarcusDenker.65.mcz
Keymapping-Shortcuts-EstebanLorenzano.65.mcz
Keymapping-Tests-MarcusDenker.69.mcz
Keymapping-Tools-Spec-MarcusDenker.16.mcz
Manifest-Core-MarcusDenker.111.mcz
Manifest-CriticBrowser-MarcusDenker.62.mcz
Manifest-Resources-Tests-EstebanLorenzano.9.mcz
Manifest-Tests-MarcusDenker.26.mcz
MenuRegistration-EstebanLorenzano.47.mcz
Metacello-Base-MarcusDenker.20.mcz
Metacello-Core-MarcusDenker.494.mcz
Metacello-MC-StephaneDucasse.666.mcz
Metacello-Platform.pharo20-MarcusDenker.29.mcz
Metacello-ToolBox-MarcusDenker.135.mcz
Monticello-MarcusDenker.775.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.213.mcz
MonticelloMocks-EstebanLorenzano.2.mcz
Morphic-EstebanLorenzano.1369.mcz
MorphicTests-MarcusDenker.67.mcz
Multilingual-Encodings-MarcusDenker.39.mcz
Multilingual-Languages-MarcusDenker.30.mcz
Multilingual-Tests-MarcusDenker.25.mcz
Multilingual-TextConversion-MarcusDenker.46.mcz
NECompletion-MarcusDenker.99.mcz
NOCompletion-MarcusDenker.34.mcz
NativeBoost-Core-EstebanLorenzano.116.mcz
NativeBoost-Examples-EstebanLorenzano.16.mcz
NativeBoost-Mac-IgorStasenko.8.mcz
NativeBoost-Pools-IgorStasenko.12.mcz
NativeBoost-Unix-IgorStasenko.12.mcz
NativeBoost-Win32-EstebanLorenzano.35.mcz
Nautilus-MarcusDenker.434.mcz
NautilusCommon-MarcusDenker.120.mcz
NautilusRefactoring-MarcusDenker.78.mcz
Network-Kernel-MarcusDenker.85.mcz
Network-MIME-MarcusDenker.52.mcz
Network-Mail-StephaneDucasse.14.mcz
Network-Protocols-MarcusDenker.88.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-URI-MarcusDenker.41.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-MarcusDenker.84.mcz
NetworkTests-MarcusDenker.79.mcz
NewClassOrganizer-MarcusDenker.7.mcz
NewList-MarcusDenker.24.mcz
NonInteractiveTranscript-MarcusDenker.5.mcz
PackageInfo-MarcusDenker.91.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.86.mcz
Polymorph-Widgets-MarcusDenker.775.mcz
RPackage-Core-EstebanLorenzano.214.mcz
RPackage-SystemIntegration-EstebanLorenzano.162.mcz
RPackage-Tests-MarcusDenker.109.mcz
RecentSubmissions-EstebanLorenzano.180.mcz
Refactoring-Changes-MarcusDenker.35.mcz
Refactoring-Core-MarcusDenker.169.mcz
Refactoring-Critics-MarcusDenker.30.mcz
Refactoring-Environment-StephaneDucasse.12.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-MarcusDenker.38.mcz
Refactoring-Tests-Changes-StephaneDucasse.18.mcz
Refactoring-Tests-Core-StephaneDucasse.63.mcz
Refactoring-Tests-Critics-MarcusDenker.8.mcz
Refactoring-Tests-Environment-StephaneDucasse.5.mcz
Regex-Core-MarcusDenker.22.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.19.mcz
Ring-Core-Kernel-MarcusDenker.90.mcz
Ring-Monticello-StephaneDucasse.12.mcz
Ring-Tests-Containers-MarcusDenker.9.mcz
Ring-Tests-Kernel-MarcusDenker.44.mcz
Ring-Tests-Monticello-MarcusDenker.10.mcz
SUnit-Core-MarcusDenker.66.mcz
SUnit-Help-MarcusDenker.4.mcz
SUnit-Tests-MarcusDenker.21.mcz
SUnit-UI-MarcusDenker.60.mcz
SUnit-UITesting-MarcusDenker.4.mcz
SUnit-Utilities-EstebanLorenzano.10.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.9.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.3.mcz
Settings-Monticello-MarcusDenker.6.mcz
Settings-Network-StephaneDucasse.16.mcz
Settings-Polymorph-StephaneDucasse.45.mcz
Settings-System-MarcusDenker.23.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-StephaneDucasse.158.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-StephaneDucasse.22.mcz
Spec-Builder-MarcusDenker.21.mcz
Spec-Core-MarcusDenker.88.mcz
Spec-Examples-EstebanLorenzano.18.mcz
Spec-Layout-MarcusDenker.27.mcz
Spec-Tests-EstebanLorenzano.21.mcz
Spec-Tools-MarcusDenker.89.mcz
Spec-Widgets-MarcusDenker.106.mcz
StartupPreferences-MarcusDenker.77.mcz
System-Announcements-MarcusDenker.41.mcz
System-Applications-MarcusDenker.44.mcz
System-Changes-EstebanLorenzano.198.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.79.mcz
System-FilePackage-MarcusDenker.72.mcz
System-FileRegistry-MarcusDenker.24.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-MarcusDenker.20.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.26.mcz
System-Localization-MarcusDenker.67.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Platforms-MarcusDenker.27.mcz
System-PragmaCollector-MarcusDenker.11.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.271.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.796.mcz
System-Text-EstebanLorenzano.216.mcz
System-Tools-StephaneDucasse.93.mcz
SystemProgress-MarcusDenker.5.mcz
Tests-MarcusDenker.522.mcz
Text-EstebanLorenzano.52.mcz
TextTests-MarcusDenker.3.mcz
Tools-MarcusDenker.1058.mcz
ToolsTest-MarcusDenker.denker.30.mcz
Traits-MarcusDenker.462.mcz
Transcript-MarcusDenker.6.mcz
UI-MarcusDenker.5.mcz
UIManager-MarcusDenker.98.mcz
Unicode-Initialization-MarcusDenker.4.mcz
UpdateStreamer-Core-MarcusDenker.12.mcz
UpdateStreamer-Tests-MarcusDenker.2.mcz
Zinc-Character-Encoding-Core-SvenVanCaekenberghe.5.mcz
Zinc-Character-Encoding-Tests-SvenVanCaekenberghe.3.mcz
Zinc-FileSystem-SvenVanCaekenberghe.9.mcz
Zinc-HTTP-EstebanLorenzano.346.mcz
Zinc-Patch-HTTPSocket-MarcusDenker.4.mcz
Zinc-Resource-Meta-Core-EstebanLorenzano.11.mcz
Zinc-Resource-Meta-FileSystem-MarcusDenker.3.mcz
Zinc-Resource-Meta-Tests-EstebanLorenzano.8.mcz
Zinc-System-Support-MarcusDenker.4.mcz
Zinc-Tests-SvenVanCaekenberghe.176.mcz
Zinc-Zodiac-EstebanLorenzano.26.mcz
Zodiac-Core-SvenVanCaekenberghe.27.mcz
Zodiac-Extra-NorbertHartl.6.mcz
Zodiac-Tests-SvenVanCaekenberghe.10.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'EstebanLorenzano 3/13/2013 10:57'!
script564

	^ 'AST-Core-MarcusDenker.113.mcz
AST-Semantic-StephaneDucasse.21.mcz
AST-Tests-Core-MarcusDenker.21.mcz
AST-Tests-Semantic-StephaneDucasse.5.mcz
AndreasProfiler-EstebanLorenzano.5.mcz
Announcements-Core-MarcusDenker.37.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-MarcusDenker.13.mcz
AsmJit-Core-CamilloBruni.2.mcz
AsmJit-Extension-StephaneDucasse.6.mcz
AsmJit-Instructions-CamilloBruni.3.mcz
AsmJit-Operands-CamilloBruni.3.mcz
AsmJit-StackManagement-CamilloBruni.2.mcz
AsmJit-x86-IgorStasenko.3.mcz
Balloon-MarcusDenker.91.mcz
BalloonTests-MarcusDenker.1.mcz
CI-Core-EstebanLorenzano.66.mcz
CI-Loader-MarcusDenker.1.mcz
CodeImport-MarcusDenker.12.mcz
CodeImport-Tests-MarcusDenker.8.mcz
Collections-Abstract-MarcusDenker.199.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-EstebanLorenzano.69.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.6.mcz
Collections-Sequenceable-EstebanLorenzano.130.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.131.mcz
Collections-Strings-MarcusDenker.240.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-EstebanLorenzano.82.mcz
Collections-Traits-MarcusDenker.13.mcz
Collections-Unordered-MarcusDenker.147.mcz
Collections-Weak-MarcusDenker.68.mcz
CollectionsTests-MarcusDenker.583.mcz
Compatibility-MarcusDenker.10.mcz
Compiler-EstebanLorenzano.379.mcz
CompilerTests-MarcusDenker.131.mcz
Compression-MarcusDenker.122.mcz
CompressionTests-MarcusDenker.21.mcz
ConfigurationCommandLineHandler-Core-MarcusDenker.8.mcz
ConfigurationCommandLineHandler-Tests-MarcusDenker.2.mcz
Deprecated20-MarcusDenker.32.mcz
EmergencyEvaluator-MarcusDenker.28.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-EstebanLorenzano.15.mcz
FileSystem-AnsiStreams-MarcusDenker.7.mcz
FileSystem-Core-MarcusDenker.63.mcz
FileSystem-Disk-MarcusDenker.48.mcz
FileSystem-Memory-MarcusDenker.20.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.6.mcz
FileSystem-Tests-Core-MarcusDenker.39.mcz
FileSystem-Tests-Disk-MarcusDenker.13.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-EstebanLorenzano.ducasse.294.mcz
FreeType-MarcusDenker.612.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Fuel-EstebanLorenzano.762.mcz
FuelCommandLineHandler-EstebanLorenzano.21.mcz
FuelSystem-FileRegistry-EstebanLorenzano.3.mcz
FuelTests-MaxLeske.311.mcz
FuelTools-Debugger-EstebanLorenzano.2.mcz
Gofer-Core-MarcusDenker.191.mcz
Gofer-Tests-MarcusDenker.157.mcz
Graphics-Display Objects-MarcusDenker.104.mcz
Graphics-Files-MarcusDenker.39.mcz
Graphics-Fonts-MarcusDenker.67.mcz
Graphics-Primitives-StephaneDucasse.99.mcz
Graphics-Resources-StephaneDucasse.16.mcz
Graphics-Tests-StephaneDucasse.30.mcz
Graphics-Transformations-StephaneDucasse.7.mcz
GroupManager-EstebanLorenzano.39.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-MarcusDenker.13.mcz
HelpSystem-Core-StephaneDucasse.89.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-MarcusDenker.16.mcz
HudsonBuildTools20-EstebanLorenzano.25.mcz
Kernel-EstebanLorenzano.1337.mcz
KernelTests-EstebanLorenzano.476.mcz
KeyChain-StephaneDucasse.29.mcz
Keymapping-Core-EstebanLorenzano.142.mcz
Keymapping-Pragmas-MarcusDenker.39.mcz
Keymapping-Settings-MarcusDenker.65.mcz
Keymapping-Shortcuts-EstebanLorenzano.65.mcz
Keymapping-Tests-MarcusDenker.69.mcz
Keymapping-Tools-Spec-MarcusDenker.16.mcz
Manifest-Core-MarcusDenker.111.mcz
Manifest-CriticBrowser-MarcusDenker.62.mcz
Manifest-Resources-Tests-EstebanLorenzano.9.mcz
Manifest-Tests-MarcusDenker.26.mcz
MenuRegistration-EstebanLorenzano.47.mcz
Metacello-Base-MarcusDenker.20.mcz
Metacello-Core-MarcusDenker.494.mcz
Metacello-MC-StephaneDucasse.666.mcz
Metacello-Platform.pharo20-MarcusDenker.29.mcz
Metacello-ToolBox-MarcusDenker.135.mcz
Monticello-MarcusDenker.775.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.213.mcz
MonticelloMocks-EstebanLorenzano.2.mcz
Morphic-EstebanLorenzano.1372.mcz
MorphicTests-MarcusDenker.67.mcz
Multilingual-Encodings-MarcusDenker.39.mcz
Multilingual-Languages-MarcusDenker.30.mcz
Multilingual-Tests-MarcusDenker.25.mcz
Multilingual-TextConversion-MarcusDenker.46.mcz
NECompletion-MarcusDenker.99.mcz
NOCompletion-MarcusDenker.34.mcz
NativeBoost-Core-EstebanLorenzano.116.mcz
NativeBoost-Examples-EstebanLorenzano.16.mcz
NativeBoost-Mac-IgorStasenko.8.mcz
NativeBoost-Pools-IgorStasenko.12.mcz
NativeBoost-Unix-IgorStasenko.12.mcz
NativeBoost-Win32-EstebanLorenzano.35.mcz
Nautilus-MarcusDenker.434.mcz
NautilusCommon-MarcusDenker.120.mcz
NautilusRefactoring-MarcusDenker.78.mcz
Network-Kernel-MarcusDenker.85.mcz
Network-MIME-MarcusDenker.52.mcz
Network-Mail-StephaneDucasse.14.mcz
Network-Protocols-MarcusDenker.88.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-URI-MarcusDenker.41.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-MarcusDenker.84.mcz
NetworkTests-MarcusDenker.79.mcz
NewClassOrganizer-MarcusDenker.7.mcz
NewList-MarcusDenker.24.mcz
NonInteractiveTranscript-MarcusDenker.5.mcz
PackageInfo-MarcusDenker.91.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.86.mcz
Polymorph-Widgets-MarcusDenker.775.mcz
RPackage-Core-EstebanLorenzano.214.mcz
RPackage-SystemIntegration-EstebanLorenzano.162.mcz
RPackage-Tests-MarcusDenker.109.mcz
RecentSubmissions-EstebanLorenzano.180.mcz
Refactoring-Changes-MarcusDenker.35.mcz
Refactoring-Core-MarcusDenker.169.mcz
Refactoring-Critics-MarcusDenker.30.mcz
Refactoring-Environment-StephaneDucasse.12.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-MarcusDenker.38.mcz
Refactoring-Tests-Changes-StephaneDucasse.18.mcz
Refactoring-Tests-Core-StephaneDucasse.63.mcz
Refactoring-Tests-Critics-MarcusDenker.8.mcz
Refactoring-Tests-Environment-StephaneDucasse.5.mcz
Regex-Core-MarcusDenker.22.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.19.mcz
Ring-Core-Kernel-MarcusDenker.90.mcz
Ring-Monticello-StephaneDucasse.12.mcz
Ring-Tests-Containers-MarcusDenker.9.mcz
Ring-Tests-Kernel-MarcusDenker.44.mcz
Ring-Tests-Monticello-MarcusDenker.10.mcz
SUnit-Core-MarcusDenker.66.mcz
SUnit-Help-MarcusDenker.4.mcz
SUnit-Tests-MarcusDenker.21.mcz
SUnit-UI-MarcusDenker.60.mcz
SUnit-UITesting-MarcusDenker.4.mcz
SUnit-Utilities-EstebanLorenzano.10.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.9.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.3.mcz
Settings-Monticello-MarcusDenker.6.mcz
Settings-Network-StephaneDucasse.16.mcz
Settings-Polymorph-StephaneDucasse.45.mcz
Settings-System-MarcusDenker.23.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-StephaneDucasse.158.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-StephaneDucasse.22.mcz
Spec-Builder-MarcusDenker.21.mcz
Spec-Core-MarcusDenker.88.mcz
Spec-Examples-EstebanLorenzano.18.mcz
Spec-Layout-MarcusDenker.27.mcz
Spec-Tests-EstebanLorenzano.21.mcz
Spec-Tools-MarcusDenker.89.mcz
Spec-Widgets-MarcusDenker.106.mcz
StartupPreferences-MarcusDenker.77.mcz
System-Announcements-MarcusDenker.41.mcz
System-Applications-MarcusDenker.44.mcz
System-Changes-EstebanLorenzano.198.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.79.mcz
System-FilePackage-MarcusDenker.72.mcz
System-FileRegistry-MarcusDenker.24.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-MarcusDenker.20.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.26.mcz
System-Localization-MarcusDenker.67.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Platforms-MarcusDenker.27.mcz
System-PragmaCollector-MarcusDenker.11.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.271.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.796.mcz
System-Text-EstebanLorenzano.216.mcz
System-Tools-StephaneDucasse.93.mcz
SystemProgress-MarcusDenker.5.mcz
Tests-MarcusDenker.522.mcz
Text-EstebanLorenzano.52.mcz
TextTests-MarcusDenker.3.mcz
Tools-MarcusDenker.1058.mcz
ToolsTest-MarcusDenker.denker.30.mcz
Traits-MarcusDenker.462.mcz
Transcript-MarcusDenker.6.mcz
UI-MarcusDenker.5.mcz
UIManager-MarcusDenker.98.mcz
Unicode-Initialization-MarcusDenker.4.mcz
UpdateStreamer-Core-MarcusDenker.12.mcz
UpdateStreamer-Tests-MarcusDenker.2.mcz
Zinc-Character-Encoding-Core-SvenVanCaekenberghe.5.mcz
Zinc-Character-Encoding-Tests-SvenVanCaekenberghe.3.mcz
Zinc-FileSystem-SvenVanCaekenberghe.9.mcz
Zinc-HTTP-EstebanLorenzano.346.mcz
Zinc-Patch-HTTPSocket-MarcusDenker.4.mcz
Zinc-Resource-Meta-Core-EstebanLorenzano.11.mcz
Zinc-Resource-Meta-FileSystem-MarcusDenker.3.mcz
Zinc-Resource-Meta-Tests-EstebanLorenzano.8.mcz
Zinc-System-Support-MarcusDenker.4.mcz
Zinc-Tests-SvenVanCaekenberghe.176.mcz
Zinc-Zodiac-EstebanLorenzano.26.mcz
Zodiac-Core-SvenVanCaekenberghe.27.mcz
Zodiac-Extra-NorbertHartl.6.mcz
Zodiac-Tests-SvenVanCaekenberghe.10.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/14/2013 14:31'!
script565

	^ 'AST-Core-MarcusDenker.113.mcz
AST-Semantic-StephaneDucasse.21.mcz
AST-Tests-Core-MarcusDenker.21.mcz
AST-Tests-Semantic-StephaneDucasse.5.mcz
AndreasProfiler-EstebanLorenzano.5.mcz
Announcements-Core-MarcusDenker.37.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-MarcusDenker.13.mcz
AsmJit-Core-CamilloBruni.2.mcz
AsmJit-Extension-StephaneDucasse.6.mcz
AsmJit-Instructions-CamilloBruni.3.mcz
AsmJit-Operands-CamilloBruni.3.mcz
AsmJit-StackManagement-CamilloBruni.2.mcz
AsmJit-x86-IgorStasenko.3.mcz
Balloon-MarcusDenker.91.mcz
BalloonTests-MarcusDenker.1.mcz
CI-Core-EstebanLorenzano.66.mcz
CI-Loader-MarcusDenker.1.mcz
CodeImport-MarcusDenker.12.mcz
CodeImport-Tests-MarcusDenker.8.mcz
Collections-Abstract-MarcusDenker.199.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-EstebanLorenzano.69.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.6.mcz
Collections-Sequenceable-EstebanLorenzano.130.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.131.mcz
Collections-Strings-MarcusDenker.240.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-EstebanLorenzano.82.mcz
Collections-Traits-MarcusDenker.13.mcz
Collections-Unordered-MarcusDenker.147.mcz
Collections-Weak-MarcusDenker.68.mcz
CollectionsTests-MarcusDenker.583.mcz
Compatibility-MarcusDenker.10.mcz
Compiler-EstebanLorenzano.379.mcz
CompilerTests-MarcusDenker.131.mcz
Compression-MarcusDenker.122.mcz
CompressionTests-MarcusDenker.21.mcz
ConfigurationCommandLineHandler-Core-MarcusDenker.8.mcz
ConfigurationCommandLineHandler-Tests-MarcusDenker.2.mcz
Deprecated20-MarcusDenker.32.mcz
EmergencyEvaluator-MarcusDenker.28.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-EstebanLorenzano.15.mcz
FileSystem-AnsiStreams-MarcusDenker.7.mcz
FileSystem-Core-MarcusDenker.63.mcz
FileSystem-Disk-MarcusDenker.48.mcz
FileSystem-Memory-MarcusDenker.20.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.6.mcz
FileSystem-Tests-Core-MarcusDenker.39.mcz
FileSystem-Tests-Disk-MarcusDenker.13.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-EstebanLorenzano.ducasse.294.mcz
FreeType-MarcusDenker.612.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Fuel-EstebanLorenzano.762.mcz
FuelCommandLineHandler-EstebanLorenzano.21.mcz
FuelSystem-FileRegistry-EstebanLorenzano.3.mcz
FuelTests-MaxLeske.311.mcz
FuelTools-Debugger-EstebanLorenzano.2.mcz
Gofer-Core-MarcusDenker.191.mcz
Gofer-Tests-MarcusDenker.157.mcz
Graphics-Display Objects-MarcusDenker.104.mcz
Graphics-Files-MarcusDenker.39.mcz
Graphics-Fonts-MarcusDenker.67.mcz
Graphics-Primitives-StephaneDucasse.99.mcz
Graphics-Resources-StephaneDucasse.16.mcz
Graphics-Tests-StephaneDucasse.30.mcz
Graphics-Transformations-StephaneDucasse.7.mcz
GroupManager-EstebanLorenzano.39.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-MarcusDenker.13.mcz
HelpSystem-Core-StephaneDucasse.89.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-MarcusDenker.16.mcz
HudsonBuildTools20-EstebanLorenzano.25.mcz
Kernel-EstebanLorenzano.1337.mcz
KernelTests-EstebanLorenzano.476.mcz
KeyChain-MarcusDenker.30.mcz
Keymapping-Core-EstebanLorenzano.142.mcz
Keymapping-Pragmas-MarcusDenker.39.mcz
Keymapping-Settings-MarcusDenker.65.mcz
Keymapping-Shortcuts-EstebanLorenzano.65.mcz
Keymapping-Tests-MarcusDenker.69.mcz
Keymapping-Tools-Spec-MarcusDenker.16.mcz
Manifest-Core-MarcusDenker.111.mcz
Manifest-CriticBrowser-MarcusDenker.62.mcz
Manifest-Resources-Tests-EstebanLorenzano.9.mcz
Manifest-Tests-MarcusDenker.26.mcz
MenuRegistration-EstebanLorenzano.47.mcz
Metacello-Base-MarcusDenker.20.mcz
Metacello-Core-MarcusDenker.494.mcz
Metacello-MC-StephaneDucasse.666.mcz
Metacello-Platform.pharo20-MarcusDenker.29.mcz
Metacello-ToolBox-MarcusDenker.135.mcz
Monticello-MarcusDenker.775.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.213.mcz
MonticelloMocks-EstebanLorenzano.2.mcz
Morphic-EstebanLorenzano.1372.mcz
MorphicTests-MarcusDenker.67.mcz
Multilingual-Encodings-MarcusDenker.39.mcz
Multilingual-Languages-MarcusDenker.30.mcz
Multilingual-Tests-MarcusDenker.25.mcz
Multilingual-TextConversion-MarcusDenker.46.mcz
NECompletion-MarcusDenker.99.mcz
NOCompletion-MarcusDenker.34.mcz
NativeBoost-Core-EstebanLorenzano.116.mcz
NativeBoost-Examples-EstebanLorenzano.16.mcz
NativeBoost-Mac-IgorStasenko.8.mcz
NativeBoost-Pools-IgorStasenko.12.mcz
NativeBoost-Unix-IgorStasenko.12.mcz
NativeBoost-Win32-EstebanLorenzano.35.mcz
Nautilus-MarcusDenker.434.mcz
NautilusCommon-MarcusDenker.120.mcz
NautilusRefactoring-MarcusDenker.78.mcz
Network-Kernel-MarcusDenker.85.mcz
Network-MIME-MarcusDenker.52.mcz
Network-Mail-StephaneDucasse.14.mcz
Network-Protocols-MarcusDenker.88.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-URI-MarcusDenker.41.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-MarcusDenker.84.mcz
NetworkTests-MarcusDenker.79.mcz
NewClassOrganizer-MarcusDenker.7.mcz
NewList-MarcusDenker.24.mcz
NonInteractiveTranscript-MarcusDenker.5.mcz
PackageInfo-MarcusDenker.91.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.86.mcz
Polymorph-Widgets-MarcusDenker.775.mcz
RPackage-Core-EstebanLorenzano.214.mcz
RPackage-SystemIntegration-EstebanLorenzano.162.mcz
RPackage-Tests-MarcusDenker.109.mcz
RecentSubmissions-EstebanLorenzano.180.mcz
Refactoring-Changes-MarcusDenker.35.mcz
Refactoring-Core-MarcusDenker.169.mcz
Refactoring-Critics-MarcusDenker.30.mcz
Refactoring-Environment-StephaneDucasse.12.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-MarcusDenker.38.mcz
Refactoring-Tests-Changes-StephaneDucasse.18.mcz
Refactoring-Tests-Core-StephaneDucasse.63.mcz
Refactoring-Tests-Critics-MarcusDenker.8.mcz
Refactoring-Tests-Environment-StephaneDucasse.5.mcz
Regex-Core-MarcusDenker.22.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.19.mcz
Ring-Core-Kernel-MarcusDenker.90.mcz
Ring-Monticello-StephaneDucasse.12.mcz
Ring-Tests-Containers-MarcusDenker.9.mcz
Ring-Tests-Kernel-MarcusDenker.44.mcz
Ring-Tests-Monticello-MarcusDenker.10.mcz
SUnit-Core-MarcusDenker.66.mcz
SUnit-Help-MarcusDenker.4.mcz
SUnit-Tests-MarcusDenker.21.mcz
SUnit-UI-MarcusDenker.60.mcz
SUnit-UITesting-MarcusDenker.4.mcz
SUnit-Utilities-EstebanLorenzano.10.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.9.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.3.mcz
Settings-Monticello-MarcusDenker.6.mcz
Settings-Network-StephaneDucasse.16.mcz
Settings-Polymorph-StephaneDucasse.45.mcz
Settings-System-MarcusDenker.23.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-StephaneDucasse.158.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-StephaneDucasse.22.mcz
Spec-Builder-MarcusDenker.21.mcz
Spec-Core-MarcusDenker.88.mcz
Spec-Examples-EstebanLorenzano.18.mcz
Spec-Layout-MarcusDenker.27.mcz
Spec-Tests-EstebanLorenzano.21.mcz
Spec-Tools-MarcusDenker.89.mcz
Spec-Widgets-MarcusDenker.106.mcz
StartupPreferences-MarcusDenker.77.mcz
System-Announcements-MarcusDenker.41.mcz
System-Applications-MarcusDenker.44.mcz
System-Changes-EstebanLorenzano.198.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.79.mcz
System-FilePackage-MarcusDenker.72.mcz
System-FileRegistry-MarcusDenker.24.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-MarcusDenker.20.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.26.mcz
System-Localization-MarcusDenker.67.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Platforms-MarcusDenker.27.mcz
System-PragmaCollector-MarcusDenker.11.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.271.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.796.mcz
System-Text-EstebanLorenzano.216.mcz
System-Tools-StephaneDucasse.93.mcz
SystemProgress-MarcusDenker.5.mcz
Tests-MarcusDenker.522.mcz
Text-EstebanLorenzano.52.mcz
TextTests-MarcusDenker.3.mcz
Tools-MarcusDenker.1059.mcz
ToolsTest-MarcusDenker.denker.30.mcz
Traits-MarcusDenker.462.mcz
Transcript-MarcusDenker.6.mcz
UI-MarcusDenker.5.mcz
UIManager-MarcusDenker.98.mcz
Unicode-Initialization-MarcusDenker.4.mcz
UpdateStreamer-Core-MarcusDenker.12.mcz
UpdateStreamer-Tests-MarcusDenker.2.mcz
Zinc-Character-Encoding-Core-SvenVanCaekenberghe.5.mcz
Zinc-Character-Encoding-Tests-SvenVanCaekenberghe.3.mcz
Zinc-FileSystem-SvenVanCaekenberghe.9.mcz
Zinc-HTTP-EstebanLorenzano.346.mcz
Zinc-Patch-HTTPSocket-MarcusDenker.4.mcz
Zinc-Resource-Meta-Core-EstebanLorenzano.11.mcz
Zinc-Resource-Meta-FileSystem-MarcusDenker.3.mcz
Zinc-Resource-Meta-Tests-EstebanLorenzano.8.mcz
Zinc-System-Support-MarcusDenker.4.mcz
Zinc-Tests-SvenVanCaekenberghe.176.mcz
Zinc-Zodiac-EstebanLorenzano.26.mcz
Zodiac-Core-SvenVanCaekenberghe.27.mcz
Zodiac-Extra-NorbertHartl.6.mcz
Zodiac-Tests-SvenVanCaekenberghe.10.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'EstebanLorenzano 3/15/2013 16:06'!
script566

	^ 'AST-Core-MarcusDenker.113.mcz
AST-Semantic-StephaneDucasse.21.mcz
AST-Tests-Core-MarcusDenker.21.mcz
AST-Tests-Semantic-StephaneDucasse.5.mcz
AndreasProfiler-EstebanLorenzano.5.mcz
Announcements-Core-MarcusDenker.37.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-MarcusDenker.13.mcz
AsmJit-Core-CamilloBruni.2.mcz
AsmJit-Extension-StephaneDucasse.6.mcz
AsmJit-Instructions-CamilloBruni.3.mcz
AsmJit-Operands-CamilloBruni.3.mcz
AsmJit-StackManagement-CamilloBruni.2.mcz
AsmJit-x86-IgorStasenko.3.mcz
Balloon-MarcusDenker.91.mcz
BalloonTests-MarcusDenker.1.mcz
CI-Core-EstebanLorenzano.66.mcz
CI-Loader-MarcusDenker.1.mcz
CodeImport-MarcusDenker.12.mcz
CodeImport-Tests-MarcusDenker.8.mcz
Collections-Abstract-MarcusDenker.199.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-EstebanLorenzano.69.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.6.mcz
Collections-Sequenceable-EstebanLorenzano.130.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.131.mcz
Collections-Strings-MarcusDenker.240.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-EstebanLorenzano.82.mcz
Collections-Traits-MarcusDenker.13.mcz
Collections-Unordered-MarcusDenker.147.mcz
Collections-Weak-MarcusDenker.68.mcz
CollectionsTests-MarcusDenker.583.mcz
Compatibility-MarcusDenker.10.mcz
Compiler-EstebanLorenzano.379.mcz
CompilerTests-MarcusDenker.131.mcz
Compression-MarcusDenker.122.mcz
CompressionTests-MarcusDenker.21.mcz
ConfigurationCommandLineHandler-Core-MarcusDenker.8.mcz
ConfigurationCommandLineHandler-Tests-MarcusDenker.2.mcz
Deprecated20-MarcusDenker.32.mcz
EmergencyEvaluator-MarcusDenker.28.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-EstebanLorenzano.15.mcz
FileSystem-AnsiStreams-MarcusDenker.7.mcz
FileSystem-Core-EstebanLorenzano.65.mcz
FileSystem-Disk-MarcusDenker.48.mcz
FileSystem-Memory-MarcusDenker.20.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.6.mcz
FileSystem-Tests-Core-MarcusDenker.39.mcz
FileSystem-Tests-Disk-MarcusDenker.13.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-EstebanLorenzano.ducasse.294.mcz
FreeType-MarcusDenker.612.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Fuel-EstebanLorenzano.762.mcz
FuelCommandLineHandler-EstebanLorenzano.21.mcz
FuelSystem-FileRegistry-EstebanLorenzano.3.mcz
FuelTests-MaxLeske.311.mcz
FuelTools-Debugger-EstebanLorenzano.2.mcz
Gofer-Core-MarcusDenker.191.mcz
Gofer-Tests-MarcusDenker.157.mcz
Graphics-Display Objects-MarcusDenker.104.mcz
Graphics-Files-MarcusDenker.39.mcz
Graphics-Fonts-MarcusDenker.67.mcz
Graphics-Primitives-StephaneDucasse.99.mcz
Graphics-Resources-StephaneDucasse.16.mcz
Graphics-Tests-StephaneDucasse.30.mcz
Graphics-Transformations-StephaneDucasse.7.mcz
GroupManager-EstebanLorenzano.39.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-MarcusDenker.13.mcz
HelpSystem-Core-StephaneDucasse.89.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-MarcusDenker.16.mcz
HudsonBuildTools20-EstebanLorenzano.25.mcz
Kernel-EstebanLorenzano.1337.mcz
KernelTests-EstebanLorenzano.476.mcz
KeyChain-MarcusDenker.30.mcz
Keymapping-Core-EstebanLorenzano.142.mcz
Keymapping-Pragmas-MarcusDenker.39.mcz
Keymapping-Settings-MarcusDenker.65.mcz
Keymapping-Shortcuts-EstebanLorenzano.65.mcz
Keymapping-Tests-MarcusDenker.69.mcz
Keymapping-Tools-Spec-MarcusDenker.16.mcz
Manifest-Core-MarcusDenker.111.mcz
Manifest-CriticBrowser-MarcusDenker.62.mcz
Manifest-Resources-Tests-EstebanLorenzano.9.mcz
Manifest-Tests-MarcusDenker.26.mcz
MenuRegistration-EstebanLorenzano.47.mcz
Metacello-Base-MarcusDenker.20.mcz
Metacello-Core-MarcusDenker.494.mcz
Metacello-MC-StephaneDucasse.666.mcz
Metacello-Platform.pharo20-MarcusDenker.29.mcz
Metacello-ToolBox-MarcusDenker.135.mcz
Monticello-MarcusDenker.775.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.213.mcz
MonticelloMocks-EstebanLorenzano.2.mcz
Morphic-EstebanLorenzano.1372.mcz
MorphicTests-MarcusDenker.67.mcz
Multilingual-Encodings-MarcusDenker.39.mcz
Multilingual-Languages-MarcusDenker.30.mcz
Multilingual-Tests-MarcusDenker.25.mcz
Multilingual-TextConversion-MarcusDenker.46.mcz
NECompletion-MarcusDenker.99.mcz
NOCompletion-MarcusDenker.34.mcz
NativeBoost-Core-EstebanLorenzano.116.mcz
NativeBoost-Examples-EstebanLorenzano.16.mcz
NativeBoost-Mac-IgorStasenko.8.mcz
NativeBoost-Pools-IgorStasenko.12.mcz
NativeBoost-Unix-IgorStasenko.12.mcz
NativeBoost-Win32-EstebanLorenzano.35.mcz
Nautilus-MarcusDenker.434.mcz
NautilusCommon-MarcusDenker.120.mcz
NautilusRefactoring-MarcusDenker.78.mcz
Network-Kernel-MarcusDenker.85.mcz
Network-MIME-MarcusDenker.52.mcz
Network-Mail-StephaneDucasse.14.mcz
Network-Protocols-EstebanLorenzano.91.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-URI-MarcusDenker.41.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-MarcusDenker.84.mcz
NetworkTests-MarcusDenker.79.mcz
NewClassOrganizer-MarcusDenker.7.mcz
NewList-MarcusDenker.24.mcz
NonInteractiveTranscript-MarcusDenker.5.mcz
PackageInfo-MarcusDenker.91.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.86.mcz
Polymorph-Widgets-MarcusDenker.775.mcz
RPackage-Core-EstebanLorenzano.214.mcz
RPackage-SystemIntegration-EstebanLorenzano.162.mcz
RPackage-Tests-MarcusDenker.109.mcz
RecentSubmissions-EstebanLorenzano.180.mcz
Refactoring-Changes-MarcusDenker.35.mcz
Refactoring-Core-MarcusDenker.169.mcz
Refactoring-Critics-MarcusDenker.30.mcz
Refactoring-Environment-StephaneDucasse.12.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-MarcusDenker.38.mcz
Refactoring-Tests-Changes-StephaneDucasse.18.mcz
Refactoring-Tests-Core-StephaneDucasse.63.mcz
Refactoring-Tests-Critics-MarcusDenker.8.mcz
Refactoring-Tests-Environment-StephaneDucasse.5.mcz
Regex-Core-MarcusDenker.22.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.19.mcz
Ring-Core-Kernel-MarcusDenker.90.mcz
Ring-Monticello-StephaneDucasse.12.mcz
Ring-Tests-Containers-MarcusDenker.9.mcz
Ring-Tests-Kernel-MarcusDenker.44.mcz
Ring-Tests-Monticello-MarcusDenker.10.mcz
SUnit-Core-MarcusDenker.66.mcz
SUnit-Help-MarcusDenker.4.mcz
SUnit-Tests-MarcusDenker.21.mcz
SUnit-UI-MarcusDenker.60.mcz
SUnit-UITesting-MarcusDenker.4.mcz
SUnit-Utilities-EstebanLorenzano.10.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.9.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.3.mcz
Settings-Monticello-MarcusDenker.6.mcz
Settings-Network-StephaneDucasse.16.mcz
Settings-Polymorph-StephaneDucasse.45.mcz
Settings-System-MarcusDenker.23.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-StephaneDucasse.158.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-StephaneDucasse.22.mcz
Spec-Builder-MarcusDenker.21.mcz
Spec-Core-MarcusDenker.88.mcz
Spec-Examples-EstebanLorenzano.18.mcz
Spec-Layout-MarcusDenker.27.mcz
Spec-Tests-EstebanLorenzano.21.mcz
Spec-Tools-MarcusDenker.89.mcz
Spec-Widgets-MarcusDenker.106.mcz
StartupPreferences-MarcusDenker.77.mcz
System-Announcements-MarcusDenker.41.mcz
System-Applications-MarcusDenker.44.mcz
System-Changes-EstebanLorenzano.198.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.79.mcz
System-FilePackage-MarcusDenker.72.mcz
System-FileRegistry-MarcusDenker.24.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-MarcusDenker.20.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.26.mcz
System-Localization-MarcusDenker.67.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Platforms-MarcusDenker.27.mcz
System-PragmaCollector-MarcusDenker.11.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.271.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.796.mcz
System-Text-EstebanLorenzano.216.mcz
System-Tools-StephaneDucasse.93.mcz
SystemProgress-MarcusDenker.5.mcz
Tests-MarcusDenker.522.mcz
Text-EstebanLorenzano.52.mcz
TextTests-MarcusDenker.3.mcz
Tools-MarcusDenker.1059.mcz
ToolsTest-MarcusDenker.denker.30.mcz
Traits-MarcusDenker.462.mcz
Transcript-MarcusDenker.6.mcz
UI-MarcusDenker.5.mcz
UIManager-MarcusDenker.98.mcz
Unicode-Initialization-MarcusDenker.4.mcz
UpdateStreamer-Core-MarcusDenker.12.mcz
UpdateStreamer-Tests-MarcusDenker.2.mcz
Zinc-Character-Encoding-Core-SvenVanCaekenberghe.5.mcz
Zinc-Character-Encoding-Tests-SvenVanCaekenberghe.3.mcz
Zinc-FileSystem-SvenVanCaekenberghe.9.mcz
Zinc-HTTP-EstebanLorenzano.346.mcz
Zinc-Patch-HTTPSocket-MarcusDenker.4.mcz
Zinc-Resource-Meta-Core-EstebanLorenzano.11.mcz
Zinc-Resource-Meta-FileSystem-MarcusDenker.3.mcz
Zinc-Resource-Meta-Tests-EstebanLorenzano.8.mcz
Zinc-System-Support-MarcusDenker.4.mcz
Zinc-Tests-SvenVanCaekenberghe.176.mcz
Zinc-Zodiac-EstebanLorenzano.26.mcz
Zodiac-Core-SvenVanCaekenberghe.27.mcz
Zodiac-Extra-NorbertHartl.6.mcz
Zodiac-Tests-SvenVanCaekenberghe.10.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'EstebanLorenzano 3/15/2013 16:37'!
script567

	^ 'AST-Core-MarcusDenker.113.mcz
AST-Semantic-StephaneDucasse.21.mcz
AST-Tests-Core-MarcusDenker.21.mcz
AST-Tests-Semantic-StephaneDucasse.5.mcz
AndreasProfiler-EstebanLorenzano.5.mcz
Announcements-Core-MarcusDenker.37.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-MarcusDenker.13.mcz
AsmJit-Core-CamilloBruni.2.mcz
AsmJit-Extension-StephaneDucasse.6.mcz
AsmJit-Instructions-CamilloBruni.3.mcz
AsmJit-Operands-CamilloBruni.3.mcz
AsmJit-StackManagement-CamilloBruni.2.mcz
AsmJit-x86-IgorStasenko.3.mcz
Balloon-MarcusDenker.91.mcz
BalloonTests-MarcusDenker.1.mcz
CI-Core-EstebanLorenzano.66.mcz
CI-Loader-MarcusDenker.1.mcz
CodeImport-MarcusDenker.12.mcz
CodeImport-Tests-MarcusDenker.8.mcz
Collections-Abstract-MarcusDenker.199.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-EstebanLorenzano.69.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.6.mcz
Collections-Sequenceable-EstebanLorenzano.130.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.131.mcz
Collections-Strings-MarcusDenker.240.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-EstebanLorenzano.82.mcz
Collections-Traits-MarcusDenker.13.mcz
Collections-Unordered-MarcusDenker.147.mcz
Collections-Weak-MarcusDenker.68.mcz
CollectionsTests-MarcusDenker.583.mcz
Compatibility-MarcusDenker.10.mcz
Compiler-EstebanLorenzano.379.mcz
CompilerTests-MarcusDenker.131.mcz
Compression-MarcusDenker.122.mcz
CompressionTests-MarcusDenker.21.mcz
ConfigurationCommandLineHandler-Core-MarcusDenker.8.mcz
ConfigurationCommandLineHandler-Tests-MarcusDenker.2.mcz
Deprecated20-MarcusDenker.32.mcz
EmergencyEvaluator-MarcusDenker.28.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-EstebanLorenzano.15.mcz
FileSystem-AnsiStreams-MarcusDenker.7.mcz
FileSystem-Core-EstebanLorenzano.67.mcz
FileSystem-Disk-MarcusDenker.48.mcz
FileSystem-Memory-MarcusDenker.20.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.6.mcz
FileSystem-Tests-Core-MarcusDenker.39.mcz
FileSystem-Tests-Disk-MarcusDenker.13.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-EstebanLorenzano.ducasse.294.mcz
FreeType-MarcusDenker.612.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Fuel-EstebanLorenzano.762.mcz
FuelCommandLineHandler-EstebanLorenzano.21.mcz
FuelSystem-FileRegistry-EstebanLorenzano.3.mcz
FuelTests-MaxLeske.311.mcz
FuelTools-Debugger-EstebanLorenzano.2.mcz
Gofer-Core-MarcusDenker.191.mcz
Gofer-Tests-MarcusDenker.157.mcz
Graphics-Display Objects-MarcusDenker.104.mcz
Graphics-Files-MarcusDenker.39.mcz
Graphics-Fonts-MarcusDenker.67.mcz
Graphics-Primitives-StephaneDucasse.99.mcz
Graphics-Resources-StephaneDucasse.16.mcz
Graphics-Tests-StephaneDucasse.30.mcz
Graphics-Transformations-StephaneDucasse.7.mcz
GroupManager-EstebanLorenzano.39.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-MarcusDenker.13.mcz
HelpSystem-Core-StephaneDucasse.89.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-MarcusDenker.16.mcz
HudsonBuildTools20-EstebanLorenzano.25.mcz
Kernel-EstebanLorenzano.1337.mcz
KernelTests-EstebanLorenzano.476.mcz
KeyChain-MarcusDenker.30.mcz
Keymapping-Core-EstebanLorenzano.142.mcz
Keymapping-Pragmas-MarcusDenker.39.mcz
Keymapping-Settings-MarcusDenker.65.mcz
Keymapping-Shortcuts-EstebanLorenzano.65.mcz
Keymapping-Tests-MarcusDenker.69.mcz
Keymapping-Tools-Spec-MarcusDenker.16.mcz
Manifest-Core-MarcusDenker.111.mcz
Manifest-CriticBrowser-MarcusDenker.62.mcz
Manifest-Resources-Tests-EstebanLorenzano.9.mcz
Manifest-Tests-MarcusDenker.26.mcz
MenuRegistration-EstebanLorenzano.47.mcz
Metacello-Base-MarcusDenker.20.mcz
Metacello-Core-MarcusDenker.494.mcz
Metacello-MC-StephaneDucasse.666.mcz
Metacello-Platform.pharo20-MarcusDenker.29.mcz
Metacello-ToolBox-MarcusDenker.135.mcz
Monticello-MarcusDenker.775.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.213.mcz
MonticelloMocks-EstebanLorenzano.2.mcz
Morphic-EstebanLorenzano.1372.mcz
MorphicTests-MarcusDenker.67.mcz
Multilingual-Encodings-MarcusDenker.39.mcz
Multilingual-Languages-MarcusDenker.30.mcz
Multilingual-Tests-MarcusDenker.25.mcz
Multilingual-TextConversion-MarcusDenker.46.mcz
NECompletion-MarcusDenker.99.mcz
NOCompletion-MarcusDenker.34.mcz
NativeBoost-Core-EstebanLorenzano.116.mcz
NativeBoost-Examples-EstebanLorenzano.16.mcz
NativeBoost-Mac-IgorStasenko.8.mcz
NativeBoost-Pools-IgorStasenko.12.mcz
NativeBoost-Unix-IgorStasenko.12.mcz
NativeBoost-Win32-EstebanLorenzano.35.mcz
Nautilus-MarcusDenker.434.mcz
NautilusCommon-MarcusDenker.120.mcz
NautilusRefactoring-MarcusDenker.78.mcz
Network-Kernel-MarcusDenker.85.mcz
Network-MIME-MarcusDenker.52.mcz
Network-Mail-StephaneDucasse.14.mcz
Network-Protocols-EstebanLorenzano.91.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-URI-MarcusDenker.41.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-MarcusDenker.84.mcz
NetworkTests-MarcusDenker.79.mcz
NewClassOrganizer-MarcusDenker.7.mcz
NewList-MarcusDenker.24.mcz
NonInteractiveTranscript-MarcusDenker.5.mcz
PackageInfo-MarcusDenker.91.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.86.mcz
Polymorph-Widgets-MarcusDenker.775.mcz
RPackage-Core-EstebanLorenzano.214.mcz
RPackage-SystemIntegration-EstebanLorenzano.162.mcz
RPackage-Tests-MarcusDenker.109.mcz
RecentSubmissions-EstebanLorenzano.180.mcz
Refactoring-Changes-MarcusDenker.35.mcz
Refactoring-Core-MarcusDenker.169.mcz
Refactoring-Critics-MarcusDenker.30.mcz
Refactoring-Environment-StephaneDucasse.12.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-MarcusDenker.38.mcz
Refactoring-Tests-Changes-StephaneDucasse.18.mcz
Refactoring-Tests-Core-StephaneDucasse.63.mcz
Refactoring-Tests-Critics-MarcusDenker.8.mcz
Refactoring-Tests-Environment-StephaneDucasse.5.mcz
Regex-Core-MarcusDenker.22.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.19.mcz
Ring-Core-Kernel-MarcusDenker.90.mcz
Ring-Monticello-StephaneDucasse.12.mcz
Ring-Tests-Containers-MarcusDenker.9.mcz
Ring-Tests-Kernel-MarcusDenker.44.mcz
Ring-Tests-Monticello-MarcusDenker.10.mcz
SUnit-Core-MarcusDenker.66.mcz
SUnit-Help-MarcusDenker.4.mcz
SUnit-Tests-MarcusDenker.21.mcz
SUnit-UI-MarcusDenker.60.mcz
SUnit-UITesting-MarcusDenker.4.mcz
SUnit-Utilities-EstebanLorenzano.10.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.9.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.3.mcz
Settings-Monticello-MarcusDenker.6.mcz
Settings-Network-StephaneDucasse.16.mcz
Settings-Polymorph-StephaneDucasse.45.mcz
Settings-System-MarcusDenker.23.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-StephaneDucasse.158.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-StephaneDucasse.22.mcz
Spec-Builder-MarcusDenker.21.mcz
Spec-Core-MarcusDenker.88.mcz
Spec-Examples-EstebanLorenzano.18.mcz
Spec-Layout-MarcusDenker.27.mcz
Spec-Tests-EstebanLorenzano.21.mcz
Spec-Tools-MarcusDenker.89.mcz
Spec-Widgets-MarcusDenker.106.mcz
StartupPreferences-MarcusDenker.77.mcz
System-Announcements-MarcusDenker.41.mcz
System-Applications-MarcusDenker.44.mcz
System-Changes-EstebanLorenzano.198.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.79.mcz
System-FilePackage-MarcusDenker.72.mcz
System-FileRegistry-MarcusDenker.24.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-MarcusDenker.20.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.26.mcz
System-Localization-MarcusDenker.67.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Platforms-MarcusDenker.27.mcz
System-PragmaCollector-MarcusDenker.11.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.271.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.796.mcz
System-Text-EstebanLorenzano.216.mcz
System-Tools-StephaneDucasse.93.mcz
SystemProgress-MarcusDenker.5.mcz
Tests-MarcusDenker.522.mcz
Text-EstebanLorenzano.52.mcz
TextTests-MarcusDenker.3.mcz
Tools-MarcusDenker.1059.mcz
ToolsTest-MarcusDenker.denker.30.mcz
Traits-MarcusDenker.462.mcz
Transcript-MarcusDenker.6.mcz
UI-MarcusDenker.5.mcz
UIManager-MarcusDenker.98.mcz
Unicode-Initialization-MarcusDenker.4.mcz
UpdateStreamer-Core-MarcusDenker.12.mcz
UpdateStreamer-Tests-MarcusDenker.2.mcz
Zinc-Character-Encoding-Core-SvenVanCaekenberghe.5.mcz
Zinc-Character-Encoding-Tests-SvenVanCaekenberghe.3.mcz
Zinc-FileSystem-SvenVanCaekenberghe.9.mcz
Zinc-HTTP-EstebanLorenzano.346.mcz
Zinc-Patch-HTTPSocket-MarcusDenker.4.mcz
Zinc-Resource-Meta-Core-EstebanLorenzano.11.mcz
Zinc-Resource-Meta-FileSystem-MarcusDenker.3.mcz
Zinc-Resource-Meta-Tests-EstebanLorenzano.8.mcz
Zinc-System-Support-MarcusDenker.4.mcz
Zinc-Tests-SvenVanCaekenberghe.176.mcz
Zinc-Zodiac-EstebanLorenzano.26.mcz
Zodiac-Core-SvenVanCaekenberghe.27.mcz
Zodiac-Extra-NorbertHartl.6.mcz
Zodiac-Tests-SvenVanCaekenberghe.10.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'EstebanLorenzano 3/28/2013 12:29'!
script568

	^ 'AST-Core-MarcusDenker.113.mcz
AST-Semantic-StephaneDucasse.21.mcz
AST-Tests-Core-MarcusDenker.21.mcz
AST-Tests-Semantic-StephaneDucasse.5.mcz
AndreasProfiler-EstebanLorenzano.5.mcz
Announcements-Core-MarcusDenker.37.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-MarcusDenker.13.mcz
AsmJit-Core-CamilloBruni.2.mcz
AsmJit-Extension-StephaneDucasse.6.mcz
AsmJit-Instructions-CamilloBruni.3.mcz
AsmJit-Operands-CamilloBruni.3.mcz
AsmJit-StackManagement-CamilloBruni.2.mcz
AsmJit-x86-IgorStasenko.3.mcz
Balloon-MarcusDenker.91.mcz
BalloonTests-MarcusDenker.1.mcz
CI-Core-EstebanLorenzano.66.mcz
CI-Loader-MarcusDenker.1.mcz
CodeImport-MarcusDenker.12.mcz
CodeImport-Tests-MarcusDenker.8.mcz
Collections-Abstract-MarcusDenker.199.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-EstebanLorenzano.69.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.6.mcz
Collections-Sequenceable-EstebanLorenzano.130.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.131.mcz
Collections-Strings-MarcusDenker.240.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-EstebanLorenzano.82.mcz
Collections-Traits-MarcusDenker.13.mcz
Collections-Unordered-MarcusDenker.147.mcz
Collections-Weak-MarcusDenker.68.mcz
CollectionsTests-MarcusDenker.583.mcz
Compatibility-MarcusDenker.10.mcz
Compiler-EstebanLorenzano.379.mcz
CompilerTests-MarcusDenker.131.mcz
Compression-MarcusDenker.122.mcz
CompressionTests-MarcusDenker.21.mcz
ConfigurationCommandLineHandler-Core-MarcusDenker.8.mcz
ConfigurationCommandLineHandler-Tests-MarcusDenker.2.mcz
Deprecated20-MarcusDenker.32.mcz
EmergencyEvaluator-MarcusDenker.28.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-EstebanLorenzano.15.mcz
FileSystem-AnsiStreams-MarcusDenker.7.mcz
FileSystem-Core-EstebanLorenzano.67.mcz
FileSystem-Disk-MarcusDenker.48.mcz
FileSystem-Memory-MarcusDenker.20.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.6.mcz
FileSystem-Tests-Core-MarcusDenker.39.mcz
FileSystem-Tests-Disk-MarcusDenker.13.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-EstebanLorenzano.ducasse.294.mcz
FreeType-MarcusDenker.612.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Fuel-EstebanLorenzano.762.mcz
FuelCommandLineHandler-EstebanLorenzano.21.mcz
FuelSystem-FileRegistry-EstebanLorenzano.3.mcz
FuelTests-MaxLeske.311.mcz
FuelTools-Debugger-EstebanLorenzano.2.mcz
Gofer-Core-MarcusDenker.191.mcz
Gofer-Tests-MarcusDenker.157.mcz
Graphics-Display Objects-MarcusDenker.104.mcz
Graphics-Files-MarcusDenker.39.mcz
Graphics-Fonts-MarcusDenker.67.mcz
Graphics-Primitives-StephaneDucasse.99.mcz
Graphics-Resources-StephaneDucasse.16.mcz
Graphics-Tests-StephaneDucasse.30.mcz
Graphics-Transformations-StephaneDucasse.7.mcz
GroupManager-EstebanLorenzano.39.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-MarcusDenker.13.mcz
HelpSystem-Core-StephaneDucasse.89.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-MarcusDenker.16.mcz
HudsonBuildTools20-EstebanLorenzano.25.mcz
Kernel-EstebanLorenzano.1337.mcz
KernelTests-EstebanLorenzano.476.mcz
KeyChain-MarcusDenker.30.mcz
Keymapping-Core-EstebanLorenzano.142.mcz
Keymapping-Pragmas-MarcusDenker.39.mcz
Keymapping-Settings-MarcusDenker.65.mcz
Keymapping-Shortcuts-EstebanLorenzano.65.mcz
Keymapping-Tests-MarcusDenker.69.mcz
Keymapping-Tools-Spec-MarcusDenker.16.mcz
Manifest-Core-MarcusDenker.111.mcz
Manifest-CriticBrowser-EstebanLorenzano.64.mcz
Manifest-Resources-Tests-EstebanLorenzano.9.mcz
Manifest-Tests-MarcusDenker.26.mcz
MenuRegistration-EstebanLorenzano.47.mcz
Metacello-Base-MarcusDenker.20.mcz
Metacello-Core-MarcusDenker.494.mcz
Metacello-MC-StephaneDucasse.666.mcz
Metacello-Platform.pharo20-MarcusDenker.29.mcz
Metacello-ToolBox-MarcusDenker.135.mcz
Monticello-MarcusDenker.775.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.213.mcz
MonticelloMocks-EstebanLorenzano.2.mcz
Morphic-EstebanLorenzano.1372.mcz
MorphicTests-MarcusDenker.67.mcz
Multilingual-Encodings-MarcusDenker.39.mcz
Multilingual-Languages-MarcusDenker.30.mcz
Multilingual-Tests-MarcusDenker.25.mcz
Multilingual-TextConversion-MarcusDenker.46.mcz
NECompletion-MarcusDenker.99.mcz
NOCompletion-MarcusDenker.34.mcz
NativeBoost-Core-EstebanLorenzano.116.mcz
NativeBoost-Examples-EstebanLorenzano.16.mcz
NativeBoost-Mac-IgorStasenko.8.mcz
NativeBoost-Pools-IgorStasenko.12.mcz
NativeBoost-Unix-IgorStasenko.12.mcz
NativeBoost-Win32-EstebanLorenzano.35.mcz
Nautilus-MarcusDenker.434.mcz
NautilusCommon-MarcusDenker.120.mcz
NautilusRefactoring-MarcusDenker.78.mcz
Network-Kernel-MarcusDenker.85.mcz
Network-MIME-MarcusDenker.52.mcz
Network-Mail-StephaneDucasse.14.mcz
Network-Protocols-EstebanLorenzano.91.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-URI-MarcusDenker.41.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-MarcusDenker.84.mcz
NetworkTests-MarcusDenker.79.mcz
NewClassOrganizer-MarcusDenker.7.mcz
NewList-MarcusDenker.24.mcz
NonInteractiveTranscript-MarcusDenker.5.mcz
PackageInfo-MarcusDenker.91.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.86.mcz
Polymorph-Widgets-MarcusDenker.775.mcz
RPackage-Core-EstebanLorenzano.214.mcz
RPackage-SystemIntegration-EstebanLorenzano.162.mcz
RPackage-Tests-MarcusDenker.109.mcz
RecentSubmissions-EstebanLorenzano.180.mcz
Refactoring-Changes-MarcusDenker.35.mcz
Refactoring-Core-MarcusDenker.169.mcz
Refactoring-Critics-MarcusDenker.30.mcz
Refactoring-Environment-StephaneDucasse.12.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-MarcusDenker.38.mcz
Refactoring-Tests-Changes-StephaneDucasse.18.mcz
Refactoring-Tests-Core-StephaneDucasse.63.mcz
Refactoring-Tests-Critics-MarcusDenker.8.mcz
Refactoring-Tests-Environment-StephaneDucasse.5.mcz
Regex-Core-MarcusDenker.22.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.19.mcz
Ring-Core-Kernel-MarcusDenker.90.mcz
Ring-Monticello-StephaneDucasse.12.mcz
Ring-Tests-Containers-MarcusDenker.9.mcz
Ring-Tests-Kernel-MarcusDenker.44.mcz
Ring-Tests-Monticello-MarcusDenker.10.mcz
SUnit-Core-MarcusDenker.66.mcz
SUnit-Help-MarcusDenker.4.mcz
SUnit-Tests-MarcusDenker.21.mcz
SUnit-UI-MarcusDenker.60.mcz
SUnit-UITesting-MarcusDenker.4.mcz
SUnit-Utilities-EstebanLorenzano.10.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.9.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.3.mcz
Settings-Monticello-MarcusDenker.6.mcz
Settings-Network-StephaneDucasse.16.mcz
Settings-Polymorph-StephaneDucasse.45.mcz
Settings-System-MarcusDenker.23.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-StephaneDucasse.158.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-StephaneDucasse.22.mcz
Spec-Builder-MarcusDenker.21.mcz
Spec-Core-MarcusDenker.88.mcz
Spec-Examples-EstebanLorenzano.18.mcz
Spec-Layout-MarcusDenker.27.mcz
Spec-Tests-EstebanLorenzano.21.mcz
Spec-Tools-MarcusDenker.89.mcz
Spec-Widgets-MarcusDenker.106.mcz
StartupPreferences-MarcusDenker.77.mcz
System-Announcements-MarcusDenker.41.mcz
System-Applications-MarcusDenker.44.mcz
System-Changes-EstebanLorenzano.198.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.79.mcz
System-FilePackage-MarcusDenker.72.mcz
System-FileRegistry-MarcusDenker.24.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-MarcusDenker.20.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.26.mcz
System-Localization-MarcusDenker.67.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Platforms-MarcusDenker.27.mcz
System-PragmaCollector-MarcusDenker.11.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.271.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.796.mcz
System-Text-EstebanLorenzano.216.mcz
System-Tools-StephaneDucasse.93.mcz
SystemProgress-MarcusDenker.5.mcz
Tests-MarcusDenker.522.mcz
Text-EstebanLorenzano.52.mcz
TextTests-MarcusDenker.3.mcz
Tools-MarcusDenker.1059.mcz
ToolsTest-MarcusDenker.denker.30.mcz
Traits-MarcusDenker.462.mcz
Transcript-MarcusDenker.6.mcz
UI-MarcusDenker.5.mcz
UIManager-MarcusDenker.98.mcz
Unicode-Initialization-MarcusDenker.4.mcz
UpdateStreamer-Core-MarcusDenker.12.mcz
UpdateStreamer-Tests-MarcusDenker.2.mcz
Zinc-Character-Encoding-Core-SvenVanCaekenberghe.5.mcz
Zinc-Character-Encoding-Tests-SvenVanCaekenberghe.3.mcz
Zinc-FileSystem-SvenVanCaekenberghe.9.mcz
Zinc-HTTP-EstebanLorenzano.346.mcz
Zinc-Patch-HTTPSocket-MarcusDenker.4.mcz
Zinc-Resource-Meta-Core-EstebanLorenzano.11.mcz
Zinc-Resource-Meta-FileSystem-MarcusDenker.3.mcz
Zinc-Resource-Meta-Tests-EstebanLorenzano.8.mcz
Zinc-System-Support-MarcusDenker.4.mcz
Zinc-Tests-SvenVanCaekenberghe.176.mcz
Zinc-Zodiac-EstebanLorenzano.26.mcz
Zodiac-Core-SvenVanCaekenberghe.27.mcz
Zodiac-Extra-NorbertHartl.6.mcz
Zodiac-Tests-SvenVanCaekenberghe.10.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'EstebanLorenzano 4/2/2013 11:41'!
script569

	^ 'AST-Core-MarcusDenker.113.mcz
AST-Semantic-StephaneDucasse.21.mcz
AST-Tests-Core-MarcusDenker.21.mcz
AST-Tests-Semantic-StephaneDucasse.5.mcz
AndreasProfiler-EstebanLorenzano.5.mcz
Announcements-Core-MarcusDenker.37.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-MarcusDenker.13.mcz
AsmJit-Core-CamilloBruni.2.mcz
AsmJit-Extension-StephaneDucasse.6.mcz
AsmJit-Instructions-CamilloBruni.3.mcz
AsmJit-Operands-CamilloBruni.3.mcz
AsmJit-StackManagement-CamilloBruni.2.mcz
AsmJit-x86-IgorStasenko.3.mcz
Balloon-MarcusDenker.91.mcz
BalloonTests-MarcusDenker.1.mcz
CI-Core-EstebanLorenzano.66.mcz
CI-Loader-MarcusDenker.1.mcz
CodeImport-MarcusDenker.12.mcz
CodeImport-Tests-MarcusDenker.8.mcz
Collections-Abstract-MarcusDenker.199.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-EstebanLorenzano.69.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.6.mcz
Collections-Sequenceable-EstebanLorenzano.130.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.131.mcz
Collections-Strings-MarcusDenker.240.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-EstebanLorenzano.82.mcz
Collections-Traits-MarcusDenker.13.mcz
Collections-Unordered-MarcusDenker.147.mcz
Collections-Weak-MarcusDenker.68.mcz
CollectionsTests-MarcusDenker.583.mcz
Compatibility-MarcusDenker.10.mcz
Compiler-EstebanLorenzano.379.mcz
CompilerTests-MarcusDenker.131.mcz
Compression-MarcusDenker.122.mcz
CompressionTests-MarcusDenker.21.mcz
ConfigurationCommandLineHandler-Core-MarcusDenker.8.mcz
ConfigurationCommandLineHandler-Tests-MarcusDenker.2.mcz
Deprecated20-MarcusDenker.32.mcz
EmergencyEvaluator-MarcusDenker.28.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-EstebanLorenzano.15.mcz
FileSystem-AnsiStreams-MarcusDenker.7.mcz
FileSystem-Core-EstebanLorenzano.67.mcz
FileSystem-Disk-MarcusDenker.48.mcz
FileSystem-Memory-MarcusDenker.20.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.6.mcz
FileSystem-Tests-Core-MarcusDenker.39.mcz
FileSystem-Tests-Disk-MarcusDenker.13.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-EstebanLorenzano.ducasse.294.mcz
FreeType-MarcusDenker.612.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Fuel-EstebanLorenzano.762.mcz
FuelCommandLineHandler-EstebanLorenzano.21.mcz
FuelSystem-FileRegistry-EstebanLorenzano.3.mcz
FuelTests-MaxLeske.311.mcz
FuelTools-Debugger-EstebanLorenzano.2.mcz
Gofer-Core-MarcusDenker.191.mcz
Gofer-Tests-MarcusDenker.157.mcz
Graphics-Display Objects-MarcusDenker.104.mcz
Graphics-Files-MarcusDenker.39.mcz
Graphics-Fonts-MarcusDenker.67.mcz
Graphics-Primitives-StephaneDucasse.99.mcz
Graphics-Resources-StephaneDucasse.16.mcz
Graphics-Tests-StephaneDucasse.30.mcz
Graphics-Transformations-StephaneDucasse.7.mcz
GroupManager-EstebanLorenzano.39.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-MarcusDenker.13.mcz
HelpSystem-Core-StephaneDucasse.89.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-MarcusDenker.16.mcz
HudsonBuildTools20-EstebanLorenzano.25.mcz
Kernel-EstebanLorenzano.1341.mcz
KernelTests-EstebanLorenzano.476.mcz
KeyChain-MarcusDenker.30.mcz
Keymapping-Core-EstebanLorenzano.147.mcz
Keymapping-Pragmas-MarcusDenker.39.mcz
Keymapping-Settings-MarcusDenker.65.mcz
Keymapping-Shortcuts-EstebanLorenzano.65.mcz
Keymapping-Tests-MarcusDenker.69.mcz
Keymapping-Tools-Spec-MarcusDenker.16.mcz
Manifest-Core-MarcusDenker.111.mcz
Manifest-CriticBrowser-EstebanLorenzano.64.mcz
Manifest-Resources-Tests-EstebanLorenzano.9.mcz
Manifest-Tests-MarcusDenker.26.mcz
MenuRegistration-EstebanLorenzano.47.mcz
Metacello-Base-MarcusDenker.20.mcz
Metacello-Core-MarcusDenker.494.mcz
Metacello-MC-StephaneDucasse.666.mcz
Metacello-Platform.pharo20-MarcusDenker.29.mcz
Metacello-ToolBox-MarcusDenker.135.mcz
Monticello-MarcusDenker.775.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.213.mcz
MonticelloMocks-EstebanLorenzano.2.mcz
Morphic-EstebanLorenzano.1372.mcz
MorphicTests-MarcusDenker.67.mcz
Multilingual-Encodings-MarcusDenker.39.mcz
Multilingual-Languages-MarcusDenker.30.mcz
Multilingual-Tests-MarcusDenker.25.mcz
Multilingual-TextConversion-MarcusDenker.46.mcz
NECompletion-MarcusDenker.99.mcz
NOCompletion-MarcusDenker.34.mcz
NativeBoost-Core-EstebanLorenzano.116.mcz
NativeBoost-Examples-EstebanLorenzano.16.mcz
NativeBoost-Mac-IgorStasenko.8.mcz
NativeBoost-Pools-IgorStasenko.12.mcz
NativeBoost-Unix-IgorStasenko.12.mcz
NativeBoost-Win32-EstebanLorenzano.35.mcz
Nautilus-EstebanLorenzano.437.mcz
NautilusCommon-MarcusDenker.120.mcz
NautilusRefactoring-MarcusDenker.78.mcz
Network-Kernel-MarcusDenker.85.mcz
Network-MIME-MarcusDenker.52.mcz
Network-Mail-StephaneDucasse.14.mcz
Network-Protocols-EstebanLorenzano.91.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-URI-MarcusDenker.41.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-MarcusDenker.84.mcz
NetworkTests-MarcusDenker.79.mcz
NewClassOrganizer-MarcusDenker.7.mcz
NewList-MarcusDenker.24.mcz
NonInteractiveTranscript-MarcusDenker.5.mcz
PackageInfo-MarcusDenker.91.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.86.mcz
Polymorph-Widgets-MarcusDenker.775.mcz
RPackage-Core-EstebanLorenzano.214.mcz
RPackage-SystemIntegration-EstebanLorenzano.162.mcz
RPackage-Tests-MarcusDenker.109.mcz
RecentSubmissions-EstebanLorenzano.180.mcz
Refactoring-Changes-MarcusDenker.35.mcz
Refactoring-Core-MarcusDenker.169.mcz
Refactoring-Critics-MarcusDenker.30.mcz
Refactoring-Environment-StephaneDucasse.12.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-MarcusDenker.38.mcz
Refactoring-Tests-Changes-StephaneDucasse.18.mcz
Refactoring-Tests-Core-StephaneDucasse.63.mcz
Refactoring-Tests-Critics-MarcusDenker.8.mcz
Refactoring-Tests-Environment-StephaneDucasse.5.mcz
Regex-Core-MarcusDenker.22.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.19.mcz
Ring-Core-Kernel-MarcusDenker.90.mcz
Ring-Monticello-StephaneDucasse.12.mcz
Ring-Tests-Containers-MarcusDenker.9.mcz
Ring-Tests-Kernel-MarcusDenker.44.mcz
Ring-Tests-Monticello-MarcusDenker.10.mcz
SUnit-Core-MarcusDenker.66.mcz
SUnit-Help-MarcusDenker.4.mcz
SUnit-Tests-MarcusDenker.21.mcz
SUnit-UI-MarcusDenker.60.mcz
SUnit-UITesting-MarcusDenker.4.mcz
SUnit-Utilities-EstebanLorenzano.10.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.9.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.3.mcz
Settings-Monticello-MarcusDenker.6.mcz
Settings-Network-StephaneDucasse.16.mcz
Settings-Polymorph-StephaneDucasse.45.mcz
Settings-System-MarcusDenker.23.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-StephaneDucasse.158.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-StephaneDucasse.22.mcz
Spec-Builder-MarcusDenker.21.mcz
Spec-Core-MarcusDenker.88.mcz
Spec-Examples-EstebanLorenzano.18.mcz
Spec-Layout-MarcusDenker.27.mcz
Spec-Tests-EstebanLorenzano.21.mcz
Spec-Tools-MarcusDenker.89.mcz
Spec-Widgets-MarcusDenker.106.mcz
StartupPreferences-MarcusDenker.77.mcz
System-Announcements-MarcusDenker.41.mcz
System-Applications-MarcusDenker.44.mcz
System-Changes-EstebanLorenzano.198.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.79.mcz
System-FilePackage-MarcusDenker.72.mcz
System-FileRegistry-MarcusDenker.24.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-MarcusDenker.20.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.26.mcz
System-Localization-MarcusDenker.67.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Platforms-MarcusDenker.27.mcz
System-PragmaCollector-MarcusDenker.11.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.271.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-EstebanLorenzano.801.mcz
System-Text-EstebanLorenzano.216.mcz
System-Tools-StephaneDucasse.93.mcz
SystemProgress-MarcusDenker.5.mcz
Tests-MarcusDenker.522.mcz
Text-EstebanLorenzano.52.mcz
TextTests-MarcusDenker.3.mcz
Tools-MarcusDenker.1059.mcz
ToolsTest-MarcusDenker.denker.30.mcz
Traits-MarcusDenker.462.mcz
Transcript-MarcusDenker.6.mcz
UI-MarcusDenker.5.mcz
UIManager-MarcusDenker.98.mcz
Unicode-Initialization-MarcusDenker.4.mcz
UpdateStreamer-Core-MarcusDenker.12.mcz
UpdateStreamer-Tests-MarcusDenker.2.mcz
Zinc-Character-Encoding-Core-SvenVanCaekenberghe.5.mcz
Zinc-Character-Encoding-Tests-SvenVanCaekenberghe.3.mcz
Zinc-FileSystem-SvenVanCaekenberghe.9.mcz
Zinc-HTTP-EstebanLorenzano.346.mcz
Zinc-Patch-HTTPSocket-MarcusDenker.4.mcz
Zinc-Resource-Meta-Core-EstebanLorenzano.11.mcz
Zinc-Resource-Meta-FileSystem-MarcusDenker.3.mcz
Zinc-Resource-Meta-Tests-EstebanLorenzano.8.mcz
Zinc-System-Support-MarcusDenker.4.mcz
Zinc-Tests-SvenVanCaekenberghe.176.mcz
Zinc-Zodiac-EstebanLorenzano.26.mcz
Zodiac-Core-SvenVanCaekenberghe.27.mcz
Zodiac-Extra-NorbertHartl.6.mcz
Zodiac-Tests-SvenVanCaekenberghe.10.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'EstebanLorenzano 4/2/2013 13:02'!
script570

	^ 'AST-Core-MarcusDenker.113.mcz
AST-Semantic-StephaneDucasse.21.mcz
AST-Tests-Core-MarcusDenker.21.mcz
AST-Tests-Semantic-StephaneDucasse.5.mcz
AndreasProfiler-EstebanLorenzano.5.mcz
Announcements-Core-MarcusDenker.37.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-MarcusDenker.13.mcz
AsmJit-Core-CamilloBruni.2.mcz
AsmJit-Extension-StephaneDucasse.6.mcz
AsmJit-Instructions-CamilloBruni.3.mcz
AsmJit-Operands-CamilloBruni.3.mcz
AsmJit-StackManagement-CamilloBruni.2.mcz
AsmJit-x86-IgorStasenko.3.mcz
Balloon-MarcusDenker.91.mcz
BalloonTests-MarcusDenker.1.mcz
CI-Core-EstebanLorenzano.66.mcz
CI-Loader-MarcusDenker.1.mcz
CodeImport-MarcusDenker.12.mcz
CodeImport-Tests-MarcusDenker.8.mcz
Collections-Abstract-MarcusDenker.199.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-EstebanLorenzano.69.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.6.mcz
Collections-Sequenceable-EstebanLorenzano.130.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.131.mcz
Collections-Strings-MarcusDenker.240.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-EstebanLorenzano.82.mcz
Collections-Traits-MarcusDenker.13.mcz
Collections-Unordered-MarcusDenker.147.mcz
Collections-Weak-MarcusDenker.68.mcz
CollectionsTests-MarcusDenker.583.mcz
Compatibility-MarcusDenker.10.mcz
Compiler-EstebanLorenzano.379.mcz
CompilerTests-MarcusDenker.131.mcz
Compression-MarcusDenker.122.mcz
CompressionTests-MarcusDenker.21.mcz
ConfigurationCommandLineHandler-Core-MarcusDenker.8.mcz
ConfigurationCommandLineHandler-Tests-MarcusDenker.2.mcz
Deprecated20-MarcusDenker.32.mcz
EmergencyEvaluator-MarcusDenker.28.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-EstebanLorenzano.15.mcz
FileSystem-AnsiStreams-MarcusDenker.7.mcz
FileSystem-Core-EstebanLorenzano.67.mcz
FileSystem-Disk-MarcusDenker.48.mcz
FileSystem-Memory-MarcusDenker.20.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.6.mcz
FileSystem-Tests-Core-MarcusDenker.39.mcz
FileSystem-Tests-Disk-MarcusDenker.13.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-EstebanLorenzano.ducasse.294.mcz
FreeType-MarcusDenker.612.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Fuel-EstebanLorenzano.762.mcz
FuelCommandLineHandler-EstebanLorenzano.21.mcz
FuelSystem-FileRegistry-EstebanLorenzano.3.mcz
FuelTests-MaxLeske.311.mcz
FuelTools-Debugger-EstebanLorenzano.2.mcz
Gofer-Core-MarcusDenker.191.mcz
Gofer-Tests-MarcusDenker.157.mcz
Graphics-Display Objects-MarcusDenker.104.mcz
Graphics-Files-MarcusDenker.39.mcz
Graphics-Fonts-MarcusDenker.67.mcz
Graphics-Primitives-StephaneDucasse.99.mcz
Graphics-Resources-StephaneDucasse.16.mcz
Graphics-Tests-StephaneDucasse.30.mcz
Graphics-Transformations-StephaneDucasse.7.mcz
GroupManager-EstebanLorenzano.39.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-MarcusDenker.13.mcz
HelpSystem-Core-StephaneDucasse.89.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-MarcusDenker.16.mcz
HudsonBuildTools20-EstebanLorenzano.25.mcz
Kernel-EstebanLorenzano.1341.mcz
KernelTests-EstebanLorenzano.476.mcz
KeyChain-MarcusDenker.30.mcz
Keymapping-Core-EstebanLorenzano.147.mcz
Keymapping-Pragmas-MarcusDenker.39.mcz
Keymapping-Settings-MarcusDenker.65.mcz
Keymapping-Shortcuts-EstebanLorenzano.65.mcz
Keymapping-Tests-MarcusDenker.69.mcz
Keymapping-Tools-Spec-MarcusDenker.16.mcz
Manifest-Core-MarcusDenker.111.mcz
Manifest-CriticBrowser-EstebanLorenzano.64.mcz
Manifest-Resources-Tests-EstebanLorenzano.9.mcz
Manifest-Tests-MarcusDenker.26.mcz
MenuRegistration-EstebanLorenzano.47.mcz
Metacello-Base-MarcusDenker.20.mcz
Metacello-Core-MarcusDenker.494.mcz
Metacello-MC-StephaneDucasse.666.mcz
Metacello-Platform.pharo20-MarcusDenker.29.mcz
Metacello-ToolBox-MarcusDenker.135.mcz
Monticello-MarcusDenker.775.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-MarcusDenker.213.mcz
MonticelloMocks-EstebanLorenzano.2.mcz
Morphic-EstebanLorenzano.1372.mcz
MorphicTests-MarcusDenker.67.mcz
Multilingual-Encodings-MarcusDenker.39.mcz
Multilingual-Languages-MarcusDenker.30.mcz
Multilingual-Tests-MarcusDenker.25.mcz
Multilingual-TextConversion-MarcusDenker.46.mcz
NECompletion-MarcusDenker.99.mcz
NOCompletion-MarcusDenker.34.mcz
NativeBoost-Core-EstebanLorenzano.116.mcz
NativeBoost-Examples-EstebanLorenzano.16.mcz
NativeBoost-Mac-IgorStasenko.8.mcz
NativeBoost-Pools-IgorStasenko.12.mcz
NativeBoost-Unix-IgorStasenko.12.mcz
NativeBoost-Win32-EstebanLorenzano.35.mcz
Nautilus-EstebanLorenzano.437.mcz
NautilusCommon-MarcusDenker.120.mcz
NautilusRefactoring-MarcusDenker.78.mcz
Network-Kernel-MarcusDenker.85.mcz
Network-MIME-MarcusDenker.52.mcz
Network-Mail-StephaneDucasse.14.mcz
Network-Protocols-EstebanLorenzano.91.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-URI-MarcusDenker.41.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-MarcusDenker.84.mcz
NetworkTests-MarcusDenker.79.mcz
NewClassOrganizer-MarcusDenker.7.mcz
NewList-MarcusDenker.24.mcz
NonInteractiveTranscript-MarcusDenker.5.mcz
PackageInfo-MarcusDenker.91.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-StephaneDucasse.86.mcz
Polymorph-Widgets-MarcusDenker.775.mcz
RPackage-Core-EstebanLorenzano.214.mcz
RPackage-SystemIntegration-EstebanLorenzano.162.mcz
RPackage-Tests-MarcusDenker.109.mcz
RecentSubmissions-EstebanLorenzano.180.mcz
Refactoring-Changes-MarcusDenker.35.mcz
Refactoring-Core-MarcusDenker.169.mcz
Refactoring-Critics-MarcusDenker.30.mcz
Refactoring-Environment-StephaneDucasse.12.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-MarcusDenker.38.mcz
Refactoring-Tests-Changes-StephaneDucasse.18.mcz
Refactoring-Tests-Core-StephaneDucasse.63.mcz
Refactoring-Tests-Critics-MarcusDenker.8.mcz
Refactoring-Tests-Environment-StephaneDucasse.5.mcz
Regex-Core-MarcusDenker.22.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-MarcusDenker.19.mcz
Ring-Core-Kernel-MarcusDenker.90.mcz
Ring-Monticello-StephaneDucasse.12.mcz
Ring-Tests-Containers-MarcusDenker.9.mcz
Ring-Tests-Kernel-MarcusDenker.44.mcz
Ring-Tests-Monticello-MarcusDenker.10.mcz
SUnit-Core-MarcusDenker.66.mcz
SUnit-Help-MarcusDenker.4.mcz
SUnit-Tests-MarcusDenker.21.mcz
SUnit-UI-MarcusDenker.60.mcz
SUnit-UITesting-MarcusDenker.4.mcz
SUnit-Utilities-EstebanLorenzano.10.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.9.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.3.mcz
Settings-Monticello-MarcusDenker.6.mcz
Settings-Network-StephaneDucasse.16.mcz
Settings-Polymorph-StephaneDucasse.45.mcz
Settings-System-MarcusDenker.23.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-StephaneDucasse.158.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-StephaneDucasse.22.mcz
Spec-Builder-MarcusDenker.21.mcz
Spec-Core-MarcusDenker.88.mcz
Spec-Examples-EstebanLorenzano.18.mcz
Spec-Layout-MarcusDenker.27.mcz
Spec-Tests-EstebanLorenzano.21.mcz
Spec-Tools-MarcusDenker.89.mcz
Spec-Widgets-MarcusDenker.106.mcz
StartupPreferences-MarcusDenker.77.mcz
System-Announcements-MarcusDenker.41.mcz
System-Applications-MarcusDenker.44.mcz
System-Changes-EstebanLorenzano.198.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.79.mcz
System-FilePackage-MarcusDenker.72.mcz
System-FileRegistry-MarcusDenker.24.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-MarcusDenker.20.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.26.mcz
System-Localization-MarcusDenker.67.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Platforms-MarcusDenker.27.mcz
System-PragmaCollector-MarcusDenker.11.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.271.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-EstebanLorenzano.801.mcz
System-Text-EstebanLorenzano.216.mcz
System-Tools-StephaneDucasse.93.mcz
SystemProgress-MarcusDenker.5.mcz
Tests-MarcusDenker.522.mcz
Text-EstebanLorenzano.52.mcz
TextTests-MarcusDenker.3.mcz
Tools-MarcusDenker.1059.mcz
ToolsTest-MarcusDenker.denker.30.mcz
Traits-MarcusDenker.462.mcz
Transcript-MarcusDenker.6.mcz
UI-MarcusDenker.5.mcz
UIManager-MarcusDenker.98.mcz
Unicode-Initialization-MarcusDenker.4.mcz
UpdateStreamer-Core-MarcusDenker.12.mcz
UpdateStreamer-Tests-MarcusDenker.2.mcz
Zinc-Character-Encoding-Core-SvenVanCaekenberghe.5.mcz
Zinc-Character-Encoding-Tests-SvenVanCaekenberghe.3.mcz
Zinc-FileSystem-SvenVanCaekenberghe.9.mcz
Zinc-HTTP-EstebanLorenzano.346.mcz
Zinc-Patch-HTTPSocket-MarcusDenker.4.mcz
Zinc-Resource-Meta-Core-EstebanLorenzano.11.mcz
Zinc-Resource-Meta-FileSystem-MarcusDenker.3.mcz
Zinc-Resource-Meta-Tests-EstebanLorenzano.8.mcz
Zinc-System-Support-MarcusDenker.4.mcz
Zinc-Tests-SvenVanCaekenberghe.176.mcz
Zinc-Zodiac-EstebanLorenzano.26.mcz
Zodiac-Core-SvenVanCaekenberghe.27.mcz
Zodiac-Extra-NorbertHartl.6.mcz
Zodiac-Tests-SvenVanCaekenberghe.10.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/3/2012 23:46'!
script99

	^ 'AST-Core-MarcusDenker.94.mcz
AST-Semantic-EstebanLorenzano.16.mcz
Announcements-Core-StephaneDucasse.31.mcz
Announcements-Help-MarcusDenker.5.mcz
Announcements-Tests-Core-StephaneDucasse.11.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.84.mcz
BalloonTests-MarcusDenker.1.mcz
CodeImport-MarcusDenker.8.mcz
CodeImport-Tests-MarcusDenker.8.mcz
Collections-Abstract-MarcusDenker.164.mcz
Collections-Arithmetic-StephaneDucasse.6.mcz
Collections-Arrayed-MarcusDenker.67.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.6.mcz
Collections-Sequenceable-MarcusDenker.117.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.105.mcz
Collections-Strings-MarcusDenker.217.mcz
Collections-Support-MarcusDenker.49.mcz
Collections-Text-MarcusDenker.79.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.133.mcz
Collections-Weak-MarcusDenker.63.mcz
CollectionsTests-MarcusDenker.559.mcz
Compatibility-MarcusDenker.8.mcz
Compiler-StephaneDucasse.331.mcz
CompilerTests-MarcusDenker.108.mcz
Compression-MarcusDenker.98.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated20-EstebanLorenzano.7.mcz
EmergencyEvaluator-StephaneDucasse.27.mcz
EventModel-StephaneDucasse.1.mcz
FamFam-Icons-MarcusDenker.8.mcz
FileSystem-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Core-MarcusDenker.10.mcz
FileSystem-Disk-StephaneDucasse.9.mcz
FileSystem-Memory-EstebanLorenzano.6.mcz
FileSystem-Tests-AnsiStreams-MarcusDenker.4.mcz
FileSystem-Tests-Core-MarcusDenker.8.mcz
FileSystem-Tests-Disk-EstebanLorenzano.6.mcz
FileSystem-Tests-Memory-MarcusDenker.4.mcz
FileSystem-Zip-EstebanLorenzano.6.mcz
Files-MarcusDenker.ducasse.242.mcz
FixUnderscores-MarcusDenker.23.mcz
FreeType-EstebanLorenzano.580.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Fuel-MarcusDenker.686.mcz
FuelCommandLineHandler-MarcusDenker.4.mcz
FuelFileSystem-MarcusDenker.5.mcz
FuelFileSystemTests-MarcusDenker.3.mcz
FuelMetalevel-MarcusDenker.51.mcz
FuelMetalevelTests-MarcusDenker.44.mcz
FuelPackageLoader-MarcusDenker.106.mcz
FuelPackageLoaderTests-MarcusDenker.33.mcz
FuelTests-MarcusDenker.268.mcz
Gofer-Core-StephaneDucasse.148.mcz
Gofer-Tests-StephaneDucasse.133.mcz
Graphics-Display Objects-MarcusDenker.76.mcz
Graphics-External-MarcusDenker.11.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.55.mcz
Graphics-Primitives-MarcusDenker.82.mcz
Graphics-Resources-MarcusDenker.14.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-MarcusDenker.22.mcz
Graphics-Text-MarcusDenker.32.mcz
Graphics-Transformations-MarcusDenker.5.mcz
GroupManager-EstebanLorenzano.27.mcz
GroupManagerUI-EstebanLorenzano.14.mcz
Growl-EstebanLorenzano.8.mcz
HelpSystem-Core-StephaneDucasse.87.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HistoryCollection-EstebanLorenzano.10.mcz
Kernel-MarcusDenker.1102.mcz
KernelTests-StephaneDucasse.411.mcz
Keymapping-Core-MarcusDenker.124.mcz
Keymapping-Pragmas-MarcusDenker.16.mcz
Keymapping-Settings-MarcusDenker.63.mcz
Keymapping-Shortcuts-MarcusDenker.57.mcz
Keymapping-Tests-MarcusDenker.59.mcz
Keymapping-Tools-Spec-StephaneDucass.6.mcz
MenuRegistration-MarcusDenker.38.mcz
Monticello-MarcusDenker.601.mcz
MonticelloConfigurations-StephaneDucasse.61.mcz
MonticelloGUI-StephaneDucasse.153.mcz
Monticellomocks-MarcusDenker.1.mcz
Morphic-MarcusDenker.1168.mcz
MorphicTests-MarcusDenker.50.mcz
Multilingual-Encodings-MarcusDenker.27.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.17.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-MarcusDenker.31.mcz
Multilingual-UnicodeInitialization-MarcusDenker.2.mcz
NECompletion-MarcusDenker.23.mcz
NOCompletion-EstebanLorenzano.9.mcz
Nautilus-StephaneDucasse.285.mcz
NautilusCommon-MarcusDenker.68.mcz
NautilusRefactoring-StephaneDucasse.33.mcz
Network-Kernel-MarcusDenker.67.mcz
Network-MIME-StephaneDucasse.43.mcz
Network-Mail-MarcusDenker.12.mcz
Network-Protocols-MarcusDenker.77.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-URI-StephaneDucasse.34.mcz
Network-UUID-MarcusDenker.22.mcz
Network-Url-MarcusDenker.68.mcz
NetworkTests-MarcusDenker.68.mcz
NonInteractiveTranscript-StephaneDucasse.3.mcz
PackageInfo-MarcusDenker.77.mcz
Polymorph-EventEnhancements-MarcusDenker.13.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-MarcusDenker.12.mcz
Polymorph-Tools-Diff-MarcusDenker.77.mcz
Polymorph-Widgets-MarcusDenker.640.mcz
RPackage-Core-StephaneDucasse.125.mcz
RPackage-SystemIntegration-StephaneDucasse.99.mcz
RPackage-Tests-StephaneDucasse.62.mcz
RecentSubmissions-MarcusDenker.157.mcz
Refactoring-Changes-EstebanLorenzano.21.mcz
Refactoring-Core-EstebanLorenzano.157.mcz
Refactoring-Critics-EstebanLorenzano.14.mcz
Refactoring-Environment-EstebanLorenzano.10.mcz
Refactoring-Pharo-Platform-EstebanLorenzano.2.mcz
Refactoring-Spelling-EstebanLorenzano.29.mcz
Regex-Core-StephaneDucasse.8.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.15.mcz
Ring-Core-Kernel-StephaneDucasse.55.mcz
Ring-Monticello-StephaneDucasse.2.mcz
Ring-Tests-Containers-MarcusDenker.4.mcz
Ring-Tests-Kernel-MarcusDenker.25.mcz
SUnit-Core-MarcusDenker.25.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.4.mcz
SUnit-UI-MarcusDenker.23.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-MarcusDenker.7.mcz
Settings-FreeType-MarcusDenker.4.mcz
Settings-Graphics-MarcusDenker.14.mcz
Settings-Kernel-StephaneDucasse.3.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-StephaneDucasse.45.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-StephaneDucasse.39.mcz
Shout-MarcusDenker.138.mcz
ShoutTests-MarcusDenker.17.mcz
Spec-Bindings-EstebanLorenzano.5.mcz
Spec-Core-MarcusDenker.24.mcz
Spec-Tests-MarcusDenker.8.mcz
Spec-Tools-StephaneDucasse.27.mcz
Spec-Widgets-MarcusDenker.29.mcz
StartupPreferences-StephaneDucasse.44.mcz
System-Announcements-StephaneDucasse.9.mcz
System-Applications-EstebanLorenzano.42.mcz
System-Change Notification-MarcusDenker.25.mcz
System-Changes-MarcusDenker.139.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-CommandLine-MarcusDenker.22.mcz
System-FilePackage-MarcusDenker.66.mcz
System-FileRegistry-MarcusDenker.15.mcz
System-Finalization-StephaneDucasse.17.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.18.mcz
System-Localization-MarcusDenker.63.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-EstebanLorenzano.162.mcz
System-Platforms-StephaneDucasse.19.mcz
System-Serial Port-MarcusDenker.20.mcz
System-Settings-MarcusDenker.262.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-MarcusDenker.633.mcz
System-Text-EstebanLorenzano.210.mcz
System-Tools-MarcusDenker.83.mcz
Tests-StephaneDucasse.387.mcz
Tools-MarcusDenker.858.mcz
ToolsTest-MarcusDenker.denker.23.mcz
Traits-MarcusDenker.417.mcz
Transcript-MarcusDenker.4.mcz
TrueType-StephaneDucasse.33.mcz
UI-Basic-MarcusDenker.12.mcz
UIManager-MarcusDenker.64.mcz
Zinc-HTTP-MarcusDenker.256.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-EstebanLorenzano.131.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/13/2010 22:30'!
setToRepositoriesPassword: aPassword to: aUser
	"self new setToRepositoriesPassword: 'sd' to: 'zork'"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllHTTPRepositories: {self repository locationWithTrailingSlash . self inboxRepository locationWithTrailingSlash}. 
	self repository password: aPassword.
	self repository user: aUser.
	self inboxRepository password: aPassword.
	self inboxRepository user: aUser.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:07'!
setUpdateAndScriptVersionNumbers
	CurrentUpdateVersionNumber := self getLatestUpdateNumber + 1.
	CurrentScriptVersionNumber := self getLatestScriptNumber + 1.! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 6/17/2012 22:47'!
shortImageName
	"should be removed when the version  will be integrated in SmalltalkImage"
	
	^ Smalltalk shortImageName copyUpToLast: $. ! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 8/21/2011 15:57'!
taskForcesRepositoryUrlString
	
	^ self rootURLString , 'PharoTaskForces'! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 11/13/2010 22:21'!
theScriptLoaderPackageName
	^'ScriptLoader',  CurrentMajorVersionNumber asString copyWithout: $. ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'StephaneDucasse 5/26/2012 22:02'!
unloadPackage: aString
	"self new unloadPackage: 'Sixx'"
	| toRemove | 
	toRemove := (self allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	toRemove unload.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'stephane.ducasse 2/6/2009 17:36'!
unloadPackageNamed: aString
	"self new workingCopyFromPackageName: 'CollectionExtensions' "
	
	^ (self workingCopyFromPackageName: aString) unload
	! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'MarcusDenker 8/17/2012 15:39'!
unregisterPackage: aString

	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	MCWorkingCopy registry removeKey: toRemove package.! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'EstebanLorenzano 3/6/2013 17:58'!
update20587
	"self new update20587"
	self withUpdateLog: 'Issue 7655:	new default preferences
	https://code.google.com/p/pharo/issues/detail?id=7655	
		
Issue 7652:	Nautilus and Message browser windows do not get updated when in a window group
	https:Argument expected -> //code.google.com/p/pharo/issues/detail?id=7652
	
Issue 7654:	keybindings redirects command to alt in linux/win
	https://code.google.com/p/pharo/issues/detail?id=7654
	
Issue 7650:	''2012-07-26 16:38:48 +0200'' asDateAndTime fails
	https://code.google.com/p/pharo/issues/detail?id=7650
'.
	self loadTogether: self script561 merge: false.
	NECPreferences popupAutomaticDelay: 500.
TextEditorDialogWindow autoAccept: true.
Parser warningAllowed: true.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'EstebanLorenzano 3/7/2013 15:46'!
update20588
	"self new update20588"
	self withUpdateLog: 'Release 2.0'.
	self loadTogether: self script562 merge: false.
		ImageCleaner new cleanUpForRelease.
 	(self confirm: 'Do you wish to advance to Pharo 3.0 Unstable?
[Yes] Your system will be marked as Pharo3.0 (Unstable), and you will subsequently receive development updates for 3.0 (unstable stream).
[No] Your system will remain at Pharo 2.0.')
        ifTrue: [SystemVersion newVersion: 'Pharo3.0a'.
                        SystemVersion current date: '7 March 2013'.
                        self inform: 'You may now save this image and retrieve updates again for Pharo2.0a and beyond.']
        ifFalse: [SystemVersion newVersion: 'Pharo2.0'.].
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'EstebanLorenzano 3/8/2013 15:08'!
update20589
	"self new update20589"
	self withUpdateLog: 'Issue 7660:	comments in isAbstractClass are wrong
	https://code.google.com/p/pharo/issues/detail?id=7660
	
Issue 7659:	use more efficient setSourcePointer: in CompiledMethod
	https://code.google.com/p/pharo/issues/detail?id=7659
	
(almost the last one :)
'.
	self loadTogether: self script563 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'EstebanLorenzano 3/13/2013 10:57'!
update20590
	"self new update20590"
	self withUpdateLog: 'Issue 7345:	DNU with Glamour: PaginatedMorphTreeMorph>>setSelectedMorph:
	https://code.google.com/p/pharo/issues/detail?id=7345
	https://pharo.fogbugz.com/f/cases/7282

	'.
	self loadTogether: self script564 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/14/2013 14:31'!
update20591
	"self new update20591"
	self withUpdateLog: '10014	World menu > System > Switch User serves no purpose
	https://pharo.fogbugz.com/f/cases/10014/World-menu-System-Switch-User-serves-no-purpose
	
10004	SmalltalkImage current reportCPUandRAM > DNU
	https://pharo.fogbugz.com/f/cases/10004/SmalltalkImage-current-reportCPUandRAM-DNU
'.
	self loadTogether: self script565 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'EstebanLorenzano 3/15/2013 16:06'!
update20592
	"self new update20592"
	self withUpdateLog: '10017 ProtocolCLient do not propagate the erros from the server
	https://pharo.fogbugz.com/f/cases/10017

7627 FileReference>>deleteAll follows symlinks
	https://pharo.fogbugz.com/f/cases/7627
'.
	self loadTogether: self script566 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'EstebanLorenzano 3/15/2013 16:37'!
update20593
	"self new update20593"
	self withUpdateLog: '10027 Failing Test: FileReferenceTest>>#testDeleteAl
	https://pharo.fogbugz.com/f/cases/10027
'.
	self loadTogether: self script567 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'EstebanLorenzano 3/28/2013 12:29'!
update20594
	"self new update20594"
	self withUpdateLog: '10123 Bug in warning in CriticBrowser
	https://pharo.fogbugz.com/f/cases/10123'.
	self loadTogether: self script568 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'EstebanLorenzano 4/2/2013 11:42'!
update20595
	"self new update20595"
	Nautilus useOldStyleKeys: true.
	self withUpdateLog: '10196 Change shortcuts default settings of 2.0 to the traditional ones
UI: Misc | Milestone: Pharo2.0
	https://pharo.fogbugz.com/f/cases/10196
	
10195 Replace ugly Keymappings API on:do:
	https://pharo.fogbugz.com/f/cases/10195
	
10194 Backport to 2.0: special objects array recreation crash
	https://pharo.fogbugz.com/f/cases/10194
	
10185 Backport 2.0: 10173 ClassBuilder cannot safely modify a class why using it
	https://pharo.fogbugz.com/f/cases/10185
	
10174 Backport 2.0 Issue 10162: multiple selection of methods in method pane ...
	https://pharo.fogbugz.com/f/cases/10174
'.
	self loadTogether: self script569 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'EstebanLorenzano 4/2/2013 13:03'!
update20596
	"self new update20596"
	self withUpdateLog: 'Prepared for production.'.
	self loadTogether: self script570 merge: false.
	ImageCleaner cleanUpForRelease.
(Process allInstances 
	select: [ :p |  | ctx |
	    ctx := p suspendedContext.
	    ctx notNil and: [ ctx method  ==  (Delay>>#wait)
	        and: [ ctx sender sender sender method selector == #secondsWhenClockTicks  ]
	     ] ])
	do: #terminate.
((Workspace 
	openContents: '"
Pharo 2.0
=======

Welcome to Pharo, a clean, innovative, free, and open-source Smalltalk-like environment.

Pharo 2.0 comes with a whole set of packages you can use to explore the system and develop your own applications. But maybe you need other stuff or feel more comfortable using a tool you already know. To easily load projects, you can open the Configurations Browser by executing:"

MetacelloConfigurationBrowser open.

"You can also open the World menu (just click the desktop) and go to Tools, then Configuration Browser.

You can find information about Pharo on http://www.pharo-project.org. In particular, you may be interested in:

- Joining us and getting help http://www.pharo-project.org/community
- Getting the Pharo By Example book (available as a free PDF): http://www.pharobyexample.org
- Watching the screencasts http://www.pharocasts.com
- Reporting problems http://www.pharo-project.org/community/issue-tracking
- Reading the forth coming book http://rmod.lille.inria.fr/pbe2
- Reading the Pharo vision document http://bit.ly/HNkEru

About this release
---------------------------
All in all, there were over 1600 issues treated in the issue tracker and 1350 improvements integrated into 2.0.

http://code.google.com/p/pharo/issues/list?can=1&q=Milestone%3D2.0+status%3AIntegrated

Read it again, yes 1350 is huge, take two minutes and have a look at the list of improvements!! Now you got the feel of the effort. And this was a true community effort. It is possible because people worldwide helped!! We want to deeply thank them.

We want to thank Inria for its constant support, in particular for the salary of Igor Stasenko and Esteban Lorenzano, and for the help in the infrastructure.

We have accomplished this huge task for a better system because we were together. Do not forget that we are working on a consortium to support our system:

- http://consortium.pharo.org (for companies and organizations)
- http://association.pharo.org (for individuals)

Our goal is to build a system so that we can make a living with our creativity and programming skills.

Read the Pharo vision document and join!!

Thanks a lot for your participation, energy and fun.

The Pharo Team

Summarized issues for 2.0
==================

UI
---

- Spec
- Widget enhancements
- Layout improvements/cleanups
- Keybindings
- New icons (famfam)
- Growl style notifications
- Revamp progress bar

Developer tools
------------------------

- Nautilus browser
- Critics browser
- Improved version diff browsing
- Spotlight
- Revamp Code Completion and smart chars
- Interactive navigation using ctrl/cmd+click over classes/methods
- Shout themes
- Andreas profiler

Networking
-----------------

- Update Zinc
- Zodiac (SSL)

System
-----------

- System Announcer
- RPackage replacing PackageInfo
- Command line tools / Headless mode
- Native boost
- Update Ring metamodel
- Fuel serializer
- Freetype fonts

Kernel
----------

- DateAndTime refactoring
- Updated FileSystem and replaced FileDirectory

VM
--

- Latests cog builds
- SSLPlugin
- FilePlugin enhancements
- SocketPlugin fixes
- Included libraries: freetype2, cairo

Cleanups
-------------

- FileDirectory removed (replaced by FileSystem)
- SmartRefStream and ReferenceStream removed (replaced by Fuel)
- PackageInfo deprecated (replaced by RPackage)

Other
-------

- Zeroconf scripts
- Continuous Integration for every aspect of our release process.

Not all the changes are reported here, but this is to give you an impression, you can find better explanation here: https://code.google.com/p/pharo/wiki/ActionsInPharo20
"'
label: 'Welcome to Pharo 2.0'))
	containingWindow 
		bounds: ((130.0@141.0) corner: (820.0@590.0)).
	self flushCaches.
! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'SeanDeNigris 7/12/2012 08:44'!
updateUpdatesList: aString
	"ScriptLoader new updateUpdatesList: 'cleanUpMethods'"
	
	self updatesListFileName asFileReference writeStreamDo: [ :str|
		str
			setToEnd;
			cr;
			nextPutAll: self currentUpdateVersionNumber asString;
			nextPutAll: '-Pha-', aString, '.cs' ]! !

!ScriptLoader methodsFor: 'private' stamp: 'SeanDeNigris 7/12/2012 08:44'!
updatesListFile
	^  self updatesListFileName asFileReference! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 2/10/2011 15:40'!
updatesListFileName

	^ 'updates', (SystemVersion current majorMinor:''), '.list'! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'lr 3/14/2010 21:13'!
verifyNewUpdate
	self repository: self class defaultMCWaitingFolder.
	self class loadLatestPackage: 'ScriptLoader' fromRepository: self repository.
	self perform: ('update' , self getLatestUpdateNumber asString) asSymbol.
	(self confirm: 'Completed loading the new update. Run all test now?')
		ifTrue: [ 
			Author fullName: 'tester'.
			Smalltalk globals at: #TestRunner ifPresent: [ :class | class open model runAll ] ]! !

!ScriptLoader methodsFor: 'private' stamp: 'al 11/1/2008 18:19'!
waitingFolderMCZFiles
	^ self class defaultMCWaitingFolder allFileNames
		reject: [:each | each =  '.DS_Store']! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/24/2008 16:45'!
withUpdateLog: aString

	self logStream nextPutAll: ' ------------------------------------------------------' ; cr.
	self logStream nextPutAll: thisContext sender selector asString. 
	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'sd 3/24/2008 17:31'!
workingCopyFromPackageName: aString
	"self new workingCopyFromPackageName: '39Deprecated' "
	
	|pa|
	pa := MCPackage named: aString.
	^ pa workingCopy 
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'sd 7/8/2006 18:20'!
writeCS: extensionAndNumber forUpdate: updateNumber
	"ScriptLoader new writeCS: '-sd.210' forUpdate: 7037"
	
	self writeCS: extensionAndNumber forUpdate: updateNumber withName: 'changeMe'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'SeanDeNigris 7/12/2012 08:44'!
writeCS: extensionAndNumber forUpdate: updateNumber withName: aSt
	"ScriptLoader new writeCS: '-md.2929' forUpdate: 7049 withName: 'cleanUpMethods'"
	
	(updateNumber asString, 'update', aSt, '.cs') asFileReference delete
		writeStreamDo: [ :stream |
			self generateCS: extensionAndNumber fromUpdate: updateNumber on: stream].
! !
ScriptLoader initialize!
